@@ -1,6 +1,7 @@
+import { takeUntil } from "rxjs/operators";
 import { Component } from "@angular/core";
 import {
-    ComponentLifecycleEventEmitter,
+    NgLifeCycleEvents,
     TupleDataObserverService,
     TupleSelector,
 } from "@synerty/vortexjs";
@@ -11,7 +12,7 @@ import { DiagramImporterStatusTuple } from "../tuples/DiagramImporterStatusTuple
     selector: "pl-diagram-status",
     templateUrl: "./status.component.html",
 })
-export class StatusComponent extends ComponentLifecycleEventEmitter {
+export class StatusComponent extends NgLifeCycleEvents {
     item: DiagramImporterStatusTuple = new DiagramImporterStatusTuple();
 
     constructor(
@@ -23,7 +24,7 @@ export class StatusComponent extends ComponentLifecycleEventEmitter {
         let ts = new TupleSelector(DiagramImporterStatusTuple.tupleName, {});
         this.tupleObserver
             .subscribeToTupleSelector(ts)
-            .takeUntil(this.onDestroyEvent)
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe(
                 (tuples: DiagramImporterStatusTuple[]) =>
                     (this.item = tuples[0])
