@@ -1,10 +1,10 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {diagramTuplePrefix} from "@peek/peek_plugin_diagram/_private/PluginNames";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { diagramTuplePrefix } from "@peek/peek_plugin_diagram/_private/PluginNames";
 
 @addTupleType
 export class DiagramImporterStatusTuple extends Tuple {
-    public static readonly tupleName = diagramTuplePrefix + "DiagramImporterStatusTuple";
+    public static readonly tupleName =
+        diagramTuplePrefix + "DiagramImporterStatusTuple";
 
     displayCompilerQueueStatus: boolean;
     displayCompilerQueueSize: number;
@@ -27,6 +27,6 @@ export class DiagramImporterStatusTuple extends Tuple {
     branchIndexCompilerLastError: string;
 
     constructor() {
-        super(DiagramImporterStatusTuple.tupleName)
+        super(DiagramImporterStatusTuple.tupleName);
     }
-}
\ No newline at end of file
+}
