@@ -9,8 +9,8 @@ Create Date: 2017-09-23 14:58:37.938811
 """
 
 # revision identifiers, used by Alembic.
-revision = 'd103b9c1eba9'
-down_revision = '558bc7fc4d36'
+revision = "d103b9c1eba9"
+down_revision = "558bc7fc4d36"
 branch_labels = None
 depends_on = None
 
@@ -20,8 +20,12 @@ import geoalchemy2
 
 
 def upgrade():
-    op.add_column('DispBase', sa.Column('dataJson', sa.String(length=500), nullable=True), schema='pl_diagram')
+    op.add_column(
+        "DispBase",
+        sa.Column("dataJson", sa.String(length=500), nullable=True),
+        schema="pl_diagram",
+    )
 
 
 def downgrade():
-    op.drop_column('DispBase', 'dataJson', schema='pl_diagram')
\ No newline at end of file
+    op.drop_column("DispBase", "dataJson", schema="pl_diagram")
