@@ -1,29 +1,31 @@
-import {Injectable} from "@angular/core";
-import {PrivateDiagramLookupService} from "@peek/peek_plugin_diagram/_private/services/PrivateDiagramLookupService";
-import {LinkedGrid} from "./LinkedGrid.web";
+import { Observable, Subject } from "rxjs";
+import { takeUntil } from "rxjs/operators";
+import { Injectable } from "@angular/core";
+import { PrivateDiagramLookupService } from "@peek/peek_plugin_diagram/_private/services/PrivateDiagramLookupService";
+import { LinkedGrid } from "./LinkedGrid.web";
 import {
     GridTuple,
-    PrivateDiagramGridLoaderServiceA
+    PrivateDiagramGridLoaderServiceA,
 } from "@peek/peek_plugin_diagram/_private/grid-loader";
-import {Subject} from "rxjs/Subject";
-import {Observable} from "rxjs/Observable";
-
-import {ComponentLifecycleEventEmitter} from "@synerty/vortexjs";
-
-
-// ----------------------------------------------------------------------------
+import { NgLifeCycleEvents } from "@synerty/vortexjs";
 
 class Cache {
-
     private cache: { [gridKey: string]: LinkedGrid } = {};
 
+    get grids(): LinkedGrid[] {
+        const grids = [];
+        for (const gridKey of Object.keys(this.cache)) {
+            grids.push(this.cache[gridKey]);
+        }
+        return grids;
+    }
+
     put(grid: LinkedGrid): void {
         this.cache[grid.gridKey] = grid;
     }
 
     get(gridKey: string): null | LinkedGrid {
-        if (!this.has(gridKey))
-            return null;
+        if (!this.has(gridKey)) return null;
         return this.cache[gridKey];
     }
 
@@ -34,18 +36,8 @@ class Cache {
     has(gridKey: string): boolean {
         return this.cache.hasOwnProperty(gridKey);
     }
-
-    get grids(): LinkedGrid[] {
-        const grids = [];
-        for (const gridKey of Object.keys(this.cache)) {
-            grids.push(this.cache[gridKey]);
-        }
-        return grids;
-    }
-
 }
 
-// ----------------------------------------------------------------------------
 /** Grid Cache
  *
  * This class has the following responsibilities:
@@ -59,7 +51,6 @@ class Cache {
  */
 @Injectable()
 export class GridCache {
-
     private updatesObservable = new Subject<LinkedGrid>();
 
     // This is the last X number of caches.
@@ -69,22 +60,37 @@ export class GridCache {
     private MAX_CACHE = 50;
 
     // TODO, There appears to be no way to tear down a service
-    private lifecycleEmitter = new ComponentLifecycleEventEmitter();
-
-    constructor(private lookupService: PrivateDiagramLookupService,
-                private gridLoader: PrivateDiagramGridLoaderServiceA) {
-
+    private NgLifeCycleEvents = new NgLifeCycleEvents();
 
+    constructor(
+        private lookupService: PrivateDiagramLookupService,
+        private gridLoader: PrivateDiagramGridLoaderServiceA
+    ) {
         // Services don't have destructors, I'm not sure how to unsubscribe.
         this.gridLoader.observable
-            .takeUntil(this.lifecycleEmitter.onDestroyEvent)
-            .subscribe((tuples: GridTuple[]) => this.processGridUpdates(tuples));
+            .pipe(takeUntil(this.NgLifeCycleEvents.onDestroyEvent))
+            .subscribe((tuples: GridTuple[]) =>
+                this.processGridUpdates(tuples)
+            );
 
         // If the lookups reload, we need to relink all the disps
-        this.lookupService.dispsNeedRelinkingObservable()
-            .takeUntil(this.lifecycleEmitter.onDestroyEvent)
+        this.lookupService
+            .dispsNeedRelinkingObservable()
+            .pipe(takeUntil(this.NgLifeCycleEvents.onDestroyEvent))
             .subscribe(() => this.relinkAllLookups());
+    }
 
+    get observable(): Observable<LinkedGrid> {
+        return this.updatesObservable;
+    }
+
+    private get linkedGrids(): LinkedGrid[] {
+        const unique = {};
+        const linkedGrids = [];
+        for (const cache of this.cacheQueue) linkedGrids.add(cache.grids);
+        return linkedGrids.filter(
+            (g) => unique[g.gridKey] === (unique[g.gridKey] = true)
+        );
     }
 
     flushCache(): void {
@@ -101,29 +107,15 @@ export class GridCache {
             linkedGrid.relinkLookups(this.lookupService);
     }
 
-    private get linkedGrids(): LinkedGrid[] {
-        const unique = {};
-        const linkedGrids = [];
-        for (const cache of this.cacheQueue)
-            linkedGrids.add(cache.grids);
-        return linkedGrids.filter(g => unique[g.gridKey] === (unique[g.gridKey] = true));
-    }
-
-    isReady(): boolean {
+    isReady(): Promise<boolean> {
         return this.gridLoader.isReady();
     }
 
-    get observable(): Observable<LinkedGrid> {
-        return this.updatesObservable;
-    }
-
-
     /** Update Watched Grids
      *
      * Change the list of grids that the GridObserver is interested in.
      */
     updateWatchedGrids(gridKeys: string[]): void {
-
         this.gridLoader.watchGrids(gridKeys);
 
         // Rotate the grid cache
@@ -133,7 +125,6 @@ export class GridCache {
         for (let linkedGrid of latestCache.grids)
             this.updatesObservable.next(linkedGrid);
 
-
         // This is the list of grids we don't have in the cache and we should
         // as the local storage for
         let gridsToGetFromStorage = [];
@@ -143,16 +134,14 @@ export class GridCache {
         let updateTimeByGridKey: { [gridKey: string]: string } = {};
         for (let gridKey of gridKeys) {
             let grid = latestCache.get(gridKey);
-            updateTimeByGridKey[gridKey] = grid == null ? null : grid.lastUpdate;
+            updateTimeByGridKey[gridKey] =
+                grid == null ? null : grid.lastUpdate;
 
-            if (grid == null)
-                gridsToGetFromStorage.push(gridKey);
+            if (grid == null) gridsToGetFromStorage.push(gridKey);
         }
 
         // Query the local storage for the grids we don't have in the cache
         this.gridLoader.loadGrids(updateTimeByGridKey, gridsToGetFromStorage);
-
-
     }
 
     /** Rotate Cache
@@ -166,7 +155,6 @@ export class GridCache {
      * The overhead is this code and X dict objects.
      */
     private rotateCache(gridKeys: string[]): Cache {
-
         // let printCache = () => {
         //     for (let i = 0; i < this.cacheQueue.length; i++) {
         //         let cache = this.cacheQueue[i];
@@ -196,8 +184,7 @@ export class GridCache {
         this.cacheQueue.unshift(latestCache);
 
         // Trim the cache
-        while (this.cacheQueue.length > this.MAX_CACHE)
-            this.cacheQueue.pop();
+        while (this.cacheQueue.length > this.MAX_CACHE) this.cacheQueue.pop();
 
         // printCache();
 
@@ -205,13 +192,11 @@ export class GridCache {
         return latestCache;
     }
 
-
     /** Process Grid Updates
      *
      */
     private processGridUpdates(gridTuples: GridTuple[]) {
-        if (this.cacheQueue.length == 0)
-            this.rotateCache([]);
+        if (this.cacheQueue.length == 0) this.rotateCache([]);
 
         const latestCache = this.cacheQueue[0];
 
@@ -225,9 +210,11 @@ export class GridCache {
 
             // If the cache differs, ignore the update
             // This really shouldn't happen.
-            if (cachedLinkedGrid != null
-                && cachedLinkedGrid.lastUpdate == gridTuple.lastUpdate) {
-                continue
+            if (
+                cachedLinkedGrid != null &&
+                cachedLinkedGrid.lastUpdate == gridTuple.lastUpdate
+            ) {
+                continue;
             }
 
             // 1) Link the grid
@@ -239,7 +226,6 @@ export class GridCache {
             // 3) Notify the observer
             this.updatesObservable.next(linkedGrid);
         }
-
     }
 
     /** Clear Grid From Cache
@@ -254,5 +240,4 @@ export class GridCache {
             cache.del(gridKey);
         }
     }
-
 }
