@@ -1,13 +1,13 @@
-import {DispLayer, DispLevel} from "@peek/peek_plugin_diagram/lookups";
+import { DispLayer, DispLevel } from "@peek/peek_plugin_diagram/lookups";
 import {
     PeekCanvasShapePropsContext,
     ShapeProp,
-    ShapePropType
+    ShapePropType,
 } from "../canvas/PeekCanvasShapePropsContext";
-import {PeekCanvasBounds} from "../canvas/PeekCanvasBounds";
-import {ModelCoordSet} from "@peek/peek_plugin_diagram/_private/tuples";
-import {deepCopy} from "@synerty/vortexjs";
-import {rotatePointAboutCenter} from "./DispUtil";
+import { PeekCanvasBounds } from "../canvas/PeekCanvasBounds";
+import { ModelCoordSet } from "@peek/peek_plugin_diagram/_private/tuples";
+import { deepCopy } from "@synerty/vortexjs";
+import { rotatePointAboutCenter } from "./DispUtil";
 
 export interface PointI {
     x: number;
@@ -18,16 +18,16 @@ export enum DispHandleTypeE {
     freeRotate,
     snapRotate,
     movePoint,
-    resizeShape
+    resizeShape,
 }
 
 export interface DispHandleI {
-    disp: DispBaseT,
-    center: PointI,
-    handleType: DispHandleTypeE,
-    box?: PeekCanvasBounds,
-    handleIndex?: number | null,
-    lastDeltaPoint?: PointI | null
+    disp: DispBaseT;
+    center: PointI;
+    handleType: DispHandleTypeE;
+    box?: PeekCanvasBounds;
+    handleIndex?: number | null;
+    lastDeltaPoint?: PointI | null;
 }
 
 export enum DispType {
@@ -38,7 +38,8 @@ export enum DispType {
     group,
     groupPointer,
     edgeTemplate,
-    null_
+    null_,
+    curvedText,
 }
 
 // ---------------------
@@ -46,7 +47,7 @@ export enum DispType {
 
 export enum DispActionEnum {
     none, // Or null
-    positionOn
+    positionOn,
 }
 
 export interface DispActionPositionOnDataT {
@@ -64,7 +65,7 @@ export type PointsT = number[];
 
 export interface DispBaseT {
     // The type of the disp
-    _tt: string,
+    _tt: string;
 
     // The ID of the disp
     id: number;
@@ -121,22 +122,23 @@ export interface DispBaseT {
     // Set by the model compiler
     // COMPUTED PROPERTY, it's computed somewhere
     dispGroup: any | null;
-
-
 }
 
 export abstract class DispBase {
-    static readonly TYPE_DT = 'DT';
-    static readonly TYPE_DPG = 'DPG';
-    static readonly TYPE_DPL = 'DPL';
-    static readonly TYPE_DE = 'DE';
-    static readonly TYPE_DG = 'DG';
-    static readonly TYPE_DGP = 'DGP';
-    static readonly TYPE_DET = 'DET';
-    static readonly TYPE_DN = 'DN';
+    static readonly TYPE_DT = "DT";
+    static readonly TYPE_DCT = "DCT";
+    static readonly TYPE_DPG = "DPG";
+    static readonly TYPE_DPL = "DPL";
+    static readonly TYPE_DE = "DE";
+    static readonly TYPE_DG = "DG";
+    static readonly TYPE_DGP = "DGP";
+    static readonly TYPE_DET = "DET";
+    static readonly TYPE_DN = "DN";
 
     static readonly DEEP_COPY_FIELDS_TO_IGNORE = [
-        'bounds', 'disps', 'dispGroup'
+        "bounds",
+        "disps",
+        "dispGroup",
     ];
 
     private static _typeMapInit = false;
@@ -146,18 +148,37 @@ export abstract class DispBase {
     private static get typeMap() {
         if (!DispBase._typeMapInit) {
             DispBase._typeMapInit = true;
-            DispBase._typeMap[DispBase.TYPE_DT] = [DispType.text, 'Text'];
-            DispBase._typeMap[DispBase.TYPE_DPG] = [DispType.polygon, 'Polygon'];
-            DispBase._typeMap[DispBase.TYPE_DPL] = [DispType.polyline, 'Polyline'];
-            DispBase._typeMap[DispBase.TYPE_DE] = [DispType.ellipse, 'Ellipse'];
-            DispBase._typeMap[DispBase.TYPE_DG] = [DispType.group, 'Group'];
-            DispBase._typeMap[DispBase.TYPE_DGP] = [DispType.groupPointer, 'GroupPointer'];
-            DispBase._typeMap[DispBase.TYPE_DET] = [DispType.edgeTemplate, 'EdgeTemplate'];
-            DispBase._typeMap[DispBase.TYPE_DN] = [DispType.null_, 'Deleted Shape'];
+            DispBase._typeMap[DispBase.TYPE_DT] = [DispType.text, "Text"];
+            DispBase._typeMap[DispBase.TYPE_DCT] = [
+                DispType.curvedText,
+                "CurvedText",
+            ];
+            DispBase._typeMap[DispBase.TYPE_DPG] = [
+                DispType.polygon,
+                "Polygon",
+            ];
+            DispBase._typeMap[DispBase.TYPE_DPL] = [
+                DispType.polyline,
+                "Polyline",
+            ];
+            DispBase._typeMap[DispBase.TYPE_DE] = [DispType.ellipse, "Ellipse"];
+            DispBase._typeMap[DispBase.TYPE_DG] = [DispType.group, "Group"];
+            DispBase._typeMap[DispBase.TYPE_DGP] = [
+                DispType.groupPointer,
+                "GroupPointer",
+            ];
+            DispBase._typeMap[DispBase.TYPE_DET] = [
+                DispType.edgeTemplate,
+                "EdgeTemplate",
+            ];
+            DispBase._typeMap[DispBase.TYPE_DN] = [
+                DispType.null_,
+                "Deleted Shape",
+            ];
         }
 
         return DispBase._typeMap;
-    };
+    }
 
     // Helper query methods
 
@@ -286,73 +307,75 @@ export abstract class DispBase {
     }
 
     static data(disp: DispBaseT): {} {
-        if (disp.d == null)
-            return {};
+        if (disp.d == null) return {};
         return JSON.parse(disp.d);
     }
 
     static setData(disp: DispBaseT, val: {} | null): void {
-        if (val == null)
-            disp.d = null;
-        else
-            disp.d = JSON.stringify(val);
+        if (val == null) disp.d = null;
+        else disp.d = JSON.stringify(val);
+    }
+
+    static setBoundsNull(disp: DispBaseT): void {
+        disp.bounds = null;
+
+        if (disp.dispGroup != null) {
+            DispBase.setBoundsNull(disp.dispGroup);
+        }
     }
 
     // ---------------
     // Delta move helpers
 
     static deltaMove(disp, dx: number, dy: number) {
-        if (disp.g == null)
-            return;
+        if (disp.g == null) return;
 
         for (let i = 0; i < disp.g.length; i += 2) {
             disp.g[i] = disp.g[i] + dx;
             disp.g[i + 1] = disp.g[i + 1] + dy;
         }
-        disp.bounds = null;
+        DispBase.setBoundsNull(disp);
     }
 
     static deltaMoveHandle(handle: DispHandleI, dx: number, dy: number) {
         const disp = <DispBaseT>handle.disp;
-        if (disp.g == null)
-            return;
+        if (disp.g == null) return;
 
         let pointIndex = handle.handleIndex * 2;
         disp.g[pointIndex] = disp.g[pointIndex] + dx;
         disp.g[pointIndex + 1] = disp.g[pointIndex + 1] + dy;
-        disp.bounds = null;
+        DispBase.setBoundsNull(disp);
     }
 
-
     static rotateAboutAxis(disp, center: PointI, rotationDegrees: number) {
-        if (disp.g == null)
-            return;
+        if (disp.g == null) return;
 
         for (let i = 0; i < disp.g.length; i += 2) {
-            let point = {x: disp.g[i], y: disp.g[i + 1]};
+            let point = { x: disp.g[i], y: disp.g[i + 1] };
             point = rotatePointAboutCenter(center, point, rotationDegrees);
             disp.g[i] = point.x;
             disp.g[i + 1] = point.y;
         }
 
-        disp.bounds = null;
+        DispBase.setBoundsNull(disp);
     }
 
     // ---------------
     // Create Handles
 
     static handlePoints(disp, margin: number): DispHandleI[] {
-        console.log(`ERROR: Handles not implemented for ${DispBase.typeOf(disp)}`);
+        console.log(
+            `ERROR: Handles not implemented for ${DispBase.typeOf(disp)}`
+        );
         return [];
     }
 
-
     // ---------------
     // Create Method
 
     static create(coordSet: ModelCoordSet, type): any {
         let newDisp: any = {
-            '_tt': type,
+            _tt: type,
         };
         let level = new DispLevel();
         level.id = coordSet.editDefaultLevelId;
@@ -373,34 +396,41 @@ export abstract class DispBase {
     // Populate shape edit context
 
     static makeShapeContext(context: PeekCanvasShapePropsContext): void {
+        context.addProp(
+            new ShapeProp(
+                ShapePropType.Layer,
+                DispBase.layer,
+                DispBase.setLayer,
+                "Layer"
+            )
+        );
 
-        context.addProp(new ShapeProp(
-            ShapePropType.Layer,
-            DispBase.layer,
-            DispBase.setLayer,
-            "Layer"
-        ));
+        context.addProp(
+            new ShapeProp(
+                ShapePropType.Level,
+                DispBase.level,
+                DispBase.setLevel,
+                "Level"
+            )
+        );
 
-        context.addProp(new ShapeProp(
-            ShapePropType.Level,
-            DispBase.level,
-            DispBase.setLevel,
-            "Level"
-        ));
+        context.addProp(
+            new ShapeProp(
+                ShapePropType.String,
+                DispBase.key,
+                DispBase.setKey,
+                "Key"
+            )
+        );
 
-        context.addProp(new ShapeProp(
-            ShapePropType.String,
-            DispBase.key,
-            DispBase.setKey,
-            "Key"
-        ));
-
-        context.addProp(new ShapeProp(
-            ShapePropType.Boolean,
-            DispBase.isSelectable,
-            DispBase.setSelectable,
-            "Selectable"
-        ));
+        context.addProp(
+            new ShapeProp(
+                ShapePropType.Boolean,
+                DispBase.isSelectable,
+                DispBase.setSelectable,
+                "Selectable"
+            )
+        );
     }
 
     // ---------------
@@ -410,15 +440,30 @@ export abstract class DispBase {
         return `Type : ${DispBase.niceName(disp)}`;
     }
 
-    static cloneDisp(disp: DispBaseT): DispBaseT {
+    static cloneDisp(
+        disp: DispBaseT,
+        options: { resetUniques?: boolean } = {}
+    ): DispBaseT {
         let copy = deepCopy(disp, DispBase.DEEP_COPY_FIELDS_TO_IGNORE);
 
         // Copy over the lookup tuples, as they would have been cloned as well.
         for (let key of Object.keys(disp)) {
-            if (disp[key] != null && disp[key]['__rst'] != null)
+            if (disp[key] != null && disp[key]["__rst"] != null)
                 copy[key] = disp[key];
         }
 
+        if (options.resetUniques) {
+            delete copy.id; // Base: Id
+            delete copy.hid; // Base: Hash ID
+            delete copy.rid; // Base: Replaces Hash ID
+            delete copy.k; // Base: Key
+            delete copy.bi; // Base: Branch ID
+            delete copy.bs; // Base: Branch Stage
+            // delete copy.gi; // Base: Group ID
+            delete copy.sk; // Polyline: Start Key
+            delete copy.ek; // Polyline: End Key
+        }
+
         return copy;
     }
 }
