@@ -1,10 +1,8 @@
-import {DispPoly, DispPolyT} from "./DispPoly";
-import {DispBase} from "./DispBase";
-import {DispPolylineEndTypeE} from "./DispPolyline";
-
+import { DispPoly, DispPolyT } from "./DispPoly";
+import { DispBase } from "./DispBase";
+import { DispPolylineEndTypeE } from "./DispPolyline";
 
 export interface DispEdgeTemplateT extends DispPolyT {
-
     // Name
     n: string;
 
@@ -15,10 +13,7 @@ export interface DispEdgeTemplateT extends DispPolyT {
     et: number | null;
 }
 
-
 export class DispEdgeTemplate extends DispPoly {
-
-
     /** Name
      *
      * The name of this line template
@@ -27,7 +22,6 @@ export class DispEdgeTemplate extends DispPoly {
         return disp.n;
     }
 
-
     /** Start Key
      *
      * The key of another disp object if the start of this EdgeTemplate is related to it
@@ -40,7 +34,6 @@ export class DispEdgeTemplate extends DispPoly {
         disp.st = val == 0 ? null : val;
     }
 
-
     /** End Key
      *
      * The key of another disp object if the end of this EdgeTemplate is related to it
@@ -53,14 +46,10 @@ export class DispEdgeTemplate extends DispPoly {
         disp.et = val == 0 ? null : val;
     }
 
-
     // ---------------
     // Represent the disp as a user friendly string
 
     static makeShapeStr(disp: DispEdgeTemplateT): string {
-        return DispBase.makeShapeStr(disp)
-            + `\nName : ${disp.n}`;
+        return DispBase.makeShapeStr(disp) + `\nName : ${disp.n}`;
     }
-
-
 }
