@@ -1,14 +1,13 @@
-import {DispBase, DispBaseT, PointI, PointsT} from "./DispBase";
-import {DispColor, DispLineStyle} from "@peek/peek_plugin_diagram/lookups";
+import { DispBase, DispBaseT, PointI, PointsT } from "./DispBase";
+import { DispColor, DispLineStyle } from "@peek/peek_plugin_diagram/lookups";
 import {
     PeekCanvasShapePropsContext,
     ShapeProp,
-    ShapePropType
+    ShapePropType,
 } from "../canvas/PeekCanvasShapePropsContext";
-import {ModelCoordSet} from "@peek/peek_plugin_diagram/_private/tuples/ModelCoordSet";
+import { ModelCoordSet } from "@peek/peek_plugin_diagram/_private/tuples/ModelCoordSet";
 
 export interface DispPolyT extends DispBaseT {
-
     // lineColor
     lc: number;
     lcl: DispColor;
@@ -19,12 +18,9 @@ export interface DispPolyT extends DispBaseT {
 
     // lineWidth
     w: number;
-
 }
 
 export abstract class DispPoly extends DispBase {
-
-
     static lineColor(disp): DispColor {
         // This is set from the short id in PrivateDiagramLookupService._linkDispLookups
         return disp.lcl;
@@ -53,7 +49,7 @@ export abstract class DispPoly extends DispBase {
 
     static setLineWidth(disp: DispPolyT, val: number): void {
         disp.w = val;
-        disp.bounds = null;
+        DispBase.setBoundsNull(disp);
     }
 
     static geom(disp): PointsT {
@@ -66,35 +62,32 @@ export abstract class DispPoly extends DispBase {
 
     static popPoint(disp): void {
         disp.g.length = disp.g.length - 2;
-        disp.bounds = null;
+        DispBase.setBoundsNull(disp);
     }
 
     static addPoint(disp, point: PointI): void {
         disp.g.push(point.x);
         disp.g.push(point.y);
-        disp.bounds = null;
+        DispBase.setBoundsNull(disp);
     }
 
     static lastPoint(disp): PointI | null {
         let len = disp.g.length;
-        if (len == 0)
-            return null;
-        return {x: disp.g[len - 1], y: disp.g[len - 2]}
+        if (len == 0) return null;
+        return { x: disp.g[len - 1], y: disp.g[len - 2] };
     }
 
-
     // ---------------
     // Support shape creating
     static create(coordSet: ModelCoordSet, type): DispPolyT {
         let newDisp = {
             ...DispBase.create(coordSet, type),
-            'g': [], // PointsT[]
-            'w': 2
+            g: [], // PointsT[]
+            w: 2,
         };
 
         DispBase.setSelectable(newDisp, true);
 
-
         let dispLineStype = new DispLineStyle();
         dispLineStype.id = coordSet.editDefaultLineStyleId;
 
@@ -112,27 +105,31 @@ export abstract class DispPoly extends DispBase {
     static makeShapeContext(context: PeekCanvasShapePropsContext): void {
         DispBase.makeShapeContext(context);
 
-        context.addProp(new ShapeProp(
-            ShapePropType.LineStyle,
-            DispPoly.lineStyle,
-            DispPoly.setLineStyle,
-            "Line Style"
-        ));
+        context.addProp(
+            new ShapeProp(
+                ShapePropType.LineStyle,
+                DispPoly.lineStyle,
+                DispPoly.setLineStyle,
+                "Line Style"
+            )
+        );
 
-        context.addProp(new ShapeProp(
-            ShapePropType.Color,
-            DispPoly.lineColor,
-            DispPoly.setLineColor,
-            "Line Color"
-        ));
+        context.addProp(
+            new ShapeProp(
+                ShapePropType.Color,
+                DispPoly.lineColor,
+                DispPoly.setLineColor,
+                "Line Color"
+            )
+        );
 
-        context.addProp(new ShapeProp(
-            ShapePropType.Integer,
-            DispPoly.lineWidth,
-            DispPoly.setLineWidth,
-            "Line Width"
-        ));
+        context.addProp(
+            new ShapeProp(
+                ShapePropType.Integer,
+                DispPoly.lineWidth,
+                DispPoly.setLineWidth,
+                "Line Width"
+            )
+        );
     }
-
-
 }
