@@ -1,20 +1,21 @@
-import {ComponentLifecycleEventEmitter} from "@synerty/vortexjs";
-import {PrivateDiagramLookupService} from "@peek/peek_plugin_diagram/_private/services/PrivateDiagramLookupService";
-import {PrivateDiagramPositionService} from "@peek/peek_plugin_diagram/_private/services/PrivateDiagramPositionService";
+import { takeUntil } from "rxjs/operators";
+import { NgLifeCycleEvents } from "@synerty/vortexjs";
+import { PrivateDiagramLookupService } from "@peek/peek_plugin_diagram/_private/services/PrivateDiagramLookupService";
+import { PrivateDiagramPositionService } from "@peek/peek_plugin_diagram/_private/services/PrivateDiagramPositionService";
 import {
     PrivateDiagramBranchContext,
-    PrivateDiagramBranchService
+    PrivateDiagramBranchService,
 } from "@peek/peek_plugin_diagram/_private/branch";
-import { BalloonMsgService } from "@synerty/peek-plugin-base-js"
-import {PeekCanvasInput} from "../canvas-input/PeekCanvasInput.web";
-import {PeekCanvasInputEditSelectDelegate} from "../canvas-input/PeekCanvasInputEditSelectDelegate.web";
-import {PeekCanvasInputSelectDelegate} from "../canvas-input/PeekCanvasInputSelectDelegate.web";
-import {PeekCanvasModel} from "./PeekCanvasModel.web";
-import {PeekCanvasConfig} from "./PeekCanvasConfig.web";
-import {EditorToolType} from "./PeekCanvasEditorToolType.web";
-import {DispLevel} from "@peek/peek_plugin_diagram/lookups";
-import {PeekCanvasEditorProps} from "./PeekCanvasEditorProps";
-import {GridObservable} from "../cache/GridObservable.web";
+import { BalloonMsgService } from "@synerty/peek-plugin-base-js";
+import { PeekCanvasInput } from "../canvas-input/PeekCanvasInput.web";
+import { PeekCanvasInputEditSelectDelegate } from "../canvas-input/PeekCanvasInputEditSelectDelegate.web";
+import { PeekCanvasInputSelectDelegate } from "../canvas-input/PeekCanvasInputSelectDelegate.web";
+import { PeekCanvasModel } from "./PeekCanvasModel.web";
+import { PeekCanvasConfig } from "./PeekCanvasConfig.web";
+import { EditorToolType } from "./PeekCanvasEditorToolType.web";
+import { DispLevel } from "@peek/peek_plugin_diagram/lookups";
+import { PeekCanvasEditorProps } from "./PeekCanvasEditorProps";
+import { GridObservable } from "../cache/GridObservable.web";
 
 /**
  * Peek Canvas Editor
@@ -23,36 +24,34 @@ import {GridObservable} from "../cache/GridObservable.web";
  *
  */
 export class PeekCanvasEditor {
-
-
     private _currentBranch: PrivateDiagramBranchContext | null = null;
 
     private readonly _props: PeekCanvasEditorProps;
 
-    constructor(public balloonMsg: BalloonMsgService,
-                public canvasInput: PeekCanvasInput,
-                public canvasModel: PeekCanvasModel,
-                private canvasConfig: PeekCanvasConfig,
-                private gridObservable: GridObservable,
-                public lookupService: PrivateDiagramLookupService,
-                private positionService: PrivateDiagramPositionService,
-                private branchService: PrivateDiagramBranchService,
-                private lifecycleEventEmitter: ComponentLifecycleEventEmitter) {
+    constructor(
+        public balloonMsg: BalloonMsgService,
+        public canvasInput: PeekCanvasInput,
+        public canvasModel: PeekCanvasModel,
+        private canvasConfig: PeekCanvasConfig,
+        private gridObservable: GridObservable,
+        public lookupService: PrivateDiagramLookupService,
+        private positionService: PrivateDiagramPositionService,
+        private branchService: PrivateDiagramBranchService,
+        private lifecycleEventEmitter: NgLifeCycleEvents
+    ) {
         this.branchService
             .startEditingWithContextObservable()
-            .takeUntil(lifecycleEventEmitter.onDestroyEvent)
+            .pipe(takeUntil(lifecycleEventEmitter.onDestroyEvent))
             .subscribe((branchContext: PrivateDiagramBranchContext) => {
                 this.gridObservable.resetAllDispComputedProperties();
                 this._props.setCanvasData(this.modelSetId, this.coordSetId);
 
-                if (this.branchContext)
-                    this.branchContext.close();
+                if (this.branchContext) this.branchContext.close();
 
                 this.branchContext = branchContext;
 
-                this.branchContext
-                    .branchUpdatedObservable
-                    .takeUntil(this.lifecycleEventEmitter.onDestroyEvent)
+                this.branchContext.branchUpdatedObservable
+                    .pipe(takeUntil(this.lifecycleEventEmitter.onDestroyEvent))
                     .subscribe((modelUpdateRequired: boolean) => {
                         if (modelUpdateRequired) {
                             this.canvasModel.recompileModel();
@@ -65,25 +64,29 @@ export class PeekCanvasEditor {
 
                 const lastPos = branchContext.branchTuple.lastEditPosition;
                 if (lastPos != null) {
-                    this.positionService
-                        .position(lastPos.coordSetKey, lastPos.x,
-                            lastPos.y, lastPos.zoom);
+                    this.positionService.position(
+                        lastPos.coordSetKey,
+                        lastPos.x,
+                        lastPos.y,
+                        lastPos.zoom
+                    );
                 }
 
                 this.setInputEditDelegate(PeekCanvasInputEditSelectDelegate);
                 this.canvasModel.selection.clearSelection();
                 this.canvasConfig.editor.active = true;
-                this.canvasConfig.updateEditedBranch(branchContext.branchTuple.key);
+                this.canvasConfig.updateEditedBranch(
+                    branchContext.branchTuple.key
+                );
                 this.canvasConfig.setModelNeedsCompiling();
             });
 
         this.branchService
             .stopEditingObservable()
-            .takeUntil(lifecycleEventEmitter.onDestroyEvent)
+            .pipe(takeUntil(lifecycleEventEmitter.onDestroyEvent))
             .subscribe(() => {
                 this.gridObservable.resetAllDispComputedProperties();
-                if (this.branchContext)
-                    this.branchContext.close();
+                if (this.branchContext) this.branchContext.close();
 
                 this.branchContext = null;
                 this.props.closeContext();
@@ -96,17 +99,17 @@ export class PeekCanvasEditor {
 
         this._props = new PeekCanvasEditorProps(this.lookupService);
 
-        this.canvasModel.selection.selectionChangedObservable()
-            .takeUntil(lifecycleEventEmitter.onDestroyEvent)
+        this.canvasModel.selection
+            .selectionChangedObservable()
+            .pipe(takeUntil(lifecycleEventEmitter.onDestroyEvent))
             .subscribe(() => {
-                if (!this.canvasConfig.editor.active)
-                    return;
+                if (!this.canvasConfig.editor.active) return;
                 this._props.setSelectedShapes(
-                    this.canvasModel, this._currentBranch.branchTuple
-                )
+                    this.canvasModel,
+                    this._currentBranch.branchTuple
+                );
             });
-    };
-
+    }
 
     // ---------------
     // Getters
@@ -128,25 +131,13 @@ export class PeekCanvasEditor {
     // ---------------
     // Shape Props
 
-    dispPropsUpdated(touchUndo: boolean = true): void {
-        this.canvasConfig.invalidate();
-
-        if (this._currentBranch == null)
-            return;
-
-        this._currentBranch.branchTuple.touchUpdateDate(false);
-
-        if (touchUndo)
-            this._currentBranch.branchTuple.touchUndo();
+    get branchContext(): PrivateDiagramBranchContext {
+        return this._currentBranch;
     }
 
     // ---------------
     // Branch Context
 
-    get branchContext(): PrivateDiagramBranchContext {
-        return this._currentBranch;
-    }
-
     set branchContext(val: PrivateDiagramBranchContext | null) {
         this.canvasConfig.editor.activeBranchTuple = null;
         this._currentBranch = val;
@@ -156,6 +147,16 @@ export class PeekCanvasEditor {
         }
     }
 
+    dispPropsUpdated(touchUndo: boolean = true): void {
+        this.canvasConfig.invalidate();
+
+        if (this._currentBranch == null) return;
+
+        this._currentBranch.branchTuple.touchUpdateDate(false);
+
+        if (touchUndo) this._currentBranch.branchTuple.touchUndo();
+    }
+
     // ---------------
     // Properties, used by UI mainly
 
@@ -188,25 +189,35 @@ export class PeekCanvasEditor {
     }
 
     save() {
-        this._currentBranch.branchTuple.lastEditPosition = ({
+        this._currentBranch.branchTuple.lastEditPosition = {
             x: this.canvasConfig.viewPort.pan.x,
             y: this.canvasConfig.viewPort.pan.y,
             zoom: this.canvasConfig.viewPort.zoom,
-            coordSetKey: this.canvasConfig.coordSet.key
-        });
+            coordSetKey: this.canvasConfig.coordSet.key,
+        };
 
-        this._currentBranch.save()
+        this._currentBranch
+            .save()
             .then(() => this.balloonMsg.showSuccess("Branch Save Successful"))
-            .catch((e) => this.balloonMsg.showError("Failed to save branch\n" + e));
+            .catch((e) =>
+                this.balloonMsg.showError("Failed to save branch\n" + e)
+            );
+    }
+
+    get canUndo(): boolean {
+        return this._currentBranch?.branchTuple.canUndo;
     }
 
     doUndo(): void {
         this._currentBranch.branchTuple.doUndo(this.lookupService);
     }
 
+    get canRedo(): boolean {
+        return this._currentBranch?.branchTuple.canRedo;
+    }
+
     doRedo(): void {
         this._currentBranch.branchTuple.doRedo(this.lookupService);
-
     }
 
     setInputEditDelegate(Delegate) {
@@ -216,8 +227,7 @@ export class PeekCanvasEditor {
             doRedo: () => this.doRedo(),
             branchContext: this.branchContext,
             editToolbarProps: this.props,
-            lookupService: this.lookupService
+            lookupService: this.lookupService,
         });
     }
-
 }
