@@ -1,19 +1,22 @@
-import {PeekCanvasConfig} from "./PeekCanvasConfig.web";
-import {GridObservable} from "../cache/GridObservable.web";
-import {ComponentLifecycleEventEmitter} from "@synerty/vortexjs";
-import {LinkedGrid} from "../cache/LinkedGrid.web";
-import {dateStr, dictKeysFromObject, dictSetFromArray} from "../DiagramUtil";
-import {PrivateDiagramLookupService} from "@peek/peek_plugin_diagram/_private/services/PrivateDiagramLookupService";
-import {DispBase, DispBaseT, DispType} from "../canvas-shapes/DispBase";
-import {PrivateDiagramBranchService} from "@peek/peek_plugin_diagram/_private/branch/PrivateDiagramBranchService";
-import {PeekCanvasModelQuery} from "./PeekCanvasModelQuery.web";
-import {PeekCanvasModelSelection} from "./PeekCanvasModelSelection.web";
-import {PeekCanvasModelOverride} from "./PeekCanvasModelOverride.web";
+import { takeUntil } from "rxjs/operators";
+import { PeekCanvasConfig } from "./PeekCanvasConfig.web";
+import { GridObservable } from "../cache/GridObservable.web";
+import { NgLifeCycleEvents } from "@synerty/vortexjs";
+import { LinkedGrid } from "../cache/LinkedGrid.web";
+import { dateStr, dictKeysFromObject, dictSetFromArray } from "../DiagramUtil";
+import { PrivateDiagramLookupService } from "@peek/peek_plugin_diagram/_private/services/PrivateDiagramLookupService";
+import { DispBase, DispBaseT, DispType } from "../canvas-shapes/DispBase";
+import { PrivateDiagramBranchService } from "@peek/peek_plugin_diagram/_private/branch/PrivateDiagramBranchService";
+import { PeekCanvasModelQuery } from "./PeekCanvasModelQuery.web";
+import { PeekCanvasModelSelection } from "./PeekCanvasModelSelection.web";
 import {
     OverrideUpdateDataI,
-    PrivateDiagramOverrideService
+    PrivateDiagramOverrideService,
 } from "@peek/peek_plugin_diagram/_private/services/PrivateDiagramOverrideService";
-import {DispGroupPointerT} from "../canvas-shapes/DispGroupPointer";
+import { DispGroupPointerT } from "../canvas-shapes/DispGroupPointer";
+import { PeekCanvasModelOverrideA } from "../canvas-override/PeekCanvasModelOverrideA";
+import { PeekCanvasModelOverrideColor } from "../canvas-override/PeekCanvasModelOverrideColor";
+import { PeekCanvasModelOverrideHighlight } from "../canvas-override/PeekCanvasModelOverrideHighlight";
 
 // import 'rxjs/add/operator/takeUntil';
 
@@ -21,7 +24,6 @@ function now(): any {
     return new Date();
 }
 
-
 interface GridOrBranchI {
     disps: any[];
     key: string;
@@ -37,7 +39,6 @@ interface GridOrBranchI {
  */
 
 export class PeekCanvasModel {
-
     private _modelSetId = null;
     private _coordSetId = null;
 
@@ -53,7 +54,6 @@ export class PeekCanvasModel {
     // Objects to be drawn on the display
     private _visibleDisps = [];
 
-
     // Does the model need an update?
     private needsUpdate = false;
 
@@ -65,51 +65,61 @@ export class PeekCanvasModel {
 
     private readonly _query: PeekCanvasModelQuery;
     private readonly _selection: PeekCanvasModelSelection;
-    private readonly _override: PeekCanvasModelOverride;
+    private readonly _overrides: PeekCanvasModelOverrideA[];
 
-    constructor(private config: PeekCanvasConfig,
-                private gridObservable: GridObservable,
-                private lookupCache: PrivateDiagramLookupService,
-                private branchService: PrivateDiagramBranchService,
-                private overrideService: PrivateDiagramOverrideService,
-                private lifecycleEventEmitter: ComponentLifecycleEventEmitter) {
+    constructor(
+        private config: PeekCanvasConfig,
+        private gridObservable: GridObservable,
+        private lookupCache: PrivateDiagramLookupService,
+        private branchService: PrivateDiagramBranchService,
+        private overrideService: PrivateDiagramOverrideService,
+        private lifecycleEventEmitter: NgLifeCycleEvents
+    ) {
         this._query = new PeekCanvasModelQuery(this);
         this._selection = new PeekCanvasModelSelection(this, this.config);
-        this._override = new PeekCanvasModelOverride(config, lookupCache);
+        this._overrides = [
+            new PeekCanvasModelOverrideColor(config, lookupCache),
+            new PeekCanvasModelOverrideHighlight(config, lookupCache),
+        ];
 
         this.needsUpdate = false;
 
         // Start the gridKey checker timer.
-        setInterval(() => this._checkGridKeysForArea(),
-            this.config.controller.updateInterval);
+        setInterval(
+            () => this._checkGridKeysForArea(),
+            this.config.controller.updateInterval
+        );
 
         // Start the draw timer.
-        setInterval(() => this._compileDisps(),
-            this.config.controller.updateInterval);
+        setInterval(
+            () => this._compileDisps(),
+            this.config.controller.updateInterval
+        );
 
         // Subscribe to grid updates, when the data store gets and update
         // from the server, we will
 
-        this.gridObservable.observableForCanvas(this.config.canvasId)
-            .takeUntil(this.lifecycleEventEmitter.onDestroyEvent)
+        this.gridObservable
+            .observableForCanvas(this.config.canvasId)
+            .pipe(takeUntil(this.lifecycleEventEmitter.onDestroyEvent))
             .subscribe((grid: LinkedGrid) => this._receiveGrid([grid]));
 
-        this.lifecycleEventEmitter.onDestroyEvent
-            .subscribe(() => this.gridObservable.unsubscribeCanvas(this.config.canvasId));
+        this.lifecycleEventEmitter.onDestroyEvent.subscribe(() =>
+            this.gridObservable.unsubscribeCanvas(this.config.canvasId)
+        );
 
         // Hook up the trigger to recompile the model
         this.config.model.needsCompiling
-            .takeUntil(this.lifecycleEventEmitter.onDestroyEvent)
-            .subscribe(() => this.needsCompiling = true);
+            .pipe(takeUntil(this.lifecycleEventEmitter.onDestroyEvent))
+            .subscribe(() => (this.needsCompiling = true));
 
         // Watch for changes to the config that effect us
         this.config.controller.coordSetChange
-            .takeUntil(this.lifecycleEventEmitter.onDestroyEvent)
+            .pipe(takeUntil(this.lifecycleEventEmitter.onDestroyEvent))
             .subscribe((coordSet) => {
                 if (coordSet == null) {
                     this._modelSetId = null;
                     this._coordSetId = null;
-
                 } else {
                     this._modelSetId = coordSet.modelSetId;
                     this._coordSetId = coordSet.id;
@@ -123,15 +133,17 @@ export class PeekCanvasModel {
         // Watch the canvas settings, if they change then request and update from
         // the cache
         this.config.viewPort.windowChange
-            .takeUntil(this.lifecycleEventEmitter.onDestroyEvent)
-            .subscribe(() => this.needsUpdate = true);
+            .pipe(takeUntil(this.lifecycleEventEmitter.onDestroyEvent))
+            .subscribe(() => (this.needsUpdate = true));
 
         // Watch the overrides, if the overrides change, then
-        this.overrideService
-            .overridesUpdatedObservable
-            .takeUntil(this.lifecycleEventEmitter.onDestroyEvent)
+        this.overrideService.overridesUpdatedObservable
+            .pipe(takeUntil(this.lifecycleEventEmitter.onDestroyEvent))
             .subscribe((data: OverrideUpdateDataI) => {
-                this._override.setOverrides(data.overrides);
+                for (const override of this._overrides) {
+                    override.setOverrides(data.overrides);
+                }
+
                 this.needsCompiling = true;
                 if (data.overridesRemoved) {
                     // Force the updates to load when they come back
@@ -146,141 +158,61 @@ export class PeekCanvasModel {
                     );
                 }
             });
-
-    };
-
-// -------------------------------------------------------------------------------------
-// reset
-// -------------------------------------------------------------------------------------
-    private reset() {
-        this.needsUpdate = false;
-        this.isUpdating = false;
-
-        this._visibleDisps = []; // Objects to be drawn on the display
-        this._gridBuffer = {}; // Store grids from the server by gridKey.
-
-        this._viewingGridKeysDict = {};
-        this._viewingGridKeysStr = "";
-    };
-
-
-// -------------------------------------------------------------------------------------
-// Request Display Updates
-// -------------------------------------------------------------------------------------
-    private _checkGridKeysForArea() {
-        if (this._coordSetId == null)
-            return;
-
-        if (!this.lookupCache.isReady())
-            return;
-
-        if (!this.needsUpdate)
-            return;
-
-        this.needsUpdate = false;
-
-        let area = this.config.viewPort.window;
-        let zoom = this.config.viewPort.zoom;
-
-        let viewingGridKeys = this.config.controller.coordSet.gridKeysForArea(area, zoom);
-
-        // If there is no change, then do nothing
-        // Should these be sorted?
-        if (viewingGridKeys.join() == this._viewingGridKeysStr)
-            return;
-
-        this._viewingGridKeysStr = viewingGridKeys.join();
-        this._viewingGridKeysDict = dictSetFromArray(viewingGridKeys);
-
-        // Remove grids we're no longer looking at.
-        for (let gridKey of dictKeysFromObject(this._gridBuffer)) {
-            if (!this._viewingGridKeysDict.hasOwnProperty(gridKey)) {
-                delete this._gridBuffer[gridKey];
-            }
-        }
-
-        // Notify the grid manager that the view has changed
-        this.gridObservable.updateDiagramWatchedGrids(
-            this.config.canvasId, viewingGridKeys
-        );
     }
 
-
-// -------------------------------------------------------------------------------------
-// Process Display Updates
-// -------------------------------------------------------------------------------------
-    /** Receive Grid
-     *
-     * NOTE: The grid data is not received in order,
-     * and sometimes the ModelGrids don't have data when no
-     * update from the server is requird.
-     *
-     * @param linkedGrids: A list of grids from the GridObservable
-     * @private
-     */
-    private _receiveGrid(linkedGrids: LinkedGrid[]) {
-
-        // Overwrite with all the new ones
-        for (let linkedGrid of linkedGrids) {
-            console.log(`PeekCanvasModel: Received grid ${linkedGrid.gridKey},  ${linkedGrid.lastUpdate}`);
-
-            // If the grid now has no data, then clear it from the model.
-            if (!linkedGrid.hasData()) {
-                if (this._gridBuffer[linkedGrid.gridKey] != null) {
-                    console.log(`PeekCanvasModel: Clearing grid ${linkedGrid.gridKey}`);
-                    delete this._gridBuffer[linkedGrid.gridKey]
-                    this.needsCompiling = true;
-                }
-                continue;
-            }
-
-            // If we're not viewing this grid any more, discard the data.
-            if (this._viewingGridKeysDict[linkedGrid.gridKey] == null)
-                continue;
-
-            // If it's not an update, also ignore it.
-            let currentGrid = this._gridBuffer[linkedGrid.gridKey];
-            if (currentGrid != null && currentGrid.lastUpdate == linkedGrid.lastUpdate)
-                continue;
-
-            console.log(`PeekCanvasModel: Applying grid ${linkedGrid.gridKey},  ${linkedGrid.lastUpdate}`);
-            this._gridBuffer[linkedGrid.gridKey] = linkedGrid;
-            this.needsCompiling = true;
-        }
-
-    }
-
-
-// -------------------------------------------------------------------------------------
-// Display Items
-// -------------------------------------------------------------------------------------
+    // -------------------------------------------------------------------------
+    // reset
 
     get query(): PeekCanvasModelQuery {
         return this._query;
     }
 
+    // -------------------------------------------------------------------------
+    // Request Display Updates
+
     get selection(): PeekCanvasModelSelection {
         return this._selection;
     }
 
+    // -------------------------------------------------------------------------
+    // Process Display Updates
+
     viewableDisps() {
         return this._visibleDisps;
     }
 
+    // -------------------------------------------------------------------------
+    // Get Overrides
+    get overrides(): PeekCanvasModelOverrideA[] {
+        return this._overrides;
+    }
+
+    // -------------------------------------------------------------------------
+    // Display Items
+    // -------------------------------------------------------------------------
+
+    recompileModel(): void {
+        this._compileDisps(true);
+    }
+
     protected _compileDisps(force = false) {
-        if (!this.needsCompiling && !force)
-            return;
+        if (!this.needsCompiling && !force) return;
 
         this.needsCompiling = false;
 
-        if (this._modelSetId == null || this._coordSetId == null)
-            return;
+        if (this._modelSetId == null || this._coordSetId == null) return;
 
         let startTime = now();
 
-        const levelsOrderedByOrder = this.lookupCache.levelsOrderedByOrder(this._coordSetId);
-        const layersOrderedByOrder = this.lookupCache.layersOrderedByOrder(this._modelSetId);
-        const viewingBranchIds = this.branchService.getVisibleBranchIds(this._coordSetId);
+        const levelsOrderedByOrder = this.lookupCache.levelsOrderedByOrder(
+            this._coordSetId
+        );
+        const layersOrderedByOrder = this.lookupCache.layersOrderedByOrder(
+            this._modelSetId
+        );
+        const viewingBranchIds = this.branchService.getVisibleBranchIds(
+            this._coordSetId
+        );
 
         let dispIndexByGridKey = {};
 
@@ -298,13 +230,12 @@ export class PeekCanvasModel {
         for (let gridKey of Object.keys(this._viewingGridKeysDict)) {
             let grid = this._gridBuffer[gridKey];
 
-            if (grid == null)
-                continue;
+            if (grid == null) continue;
 
             gridsOrBranchesToCompile.push({
                 key: grid.gridKey,
                 disps: grid.disps,
-                isBranch: false
+                isBranch: false,
             });
         }
 
@@ -321,7 +252,7 @@ export class PeekCanvasModel {
             gridsOrBranchesToCompile.push({
                 key: activeBranch.key,
                 disps: activeBranch.disps,
-                isBranch: true
+                isBranch: true,
             });
         }
 
@@ -333,55 +264,53 @@ export class PeekCanvasModel {
                 // If the branch is showing, and it replaces a hash,
                 // then add the hash it replaces
                 let replacesHashId = DispBase.replacesHashId(disp);
-                if (branchIdsActive[disp.bi] == true && replacesHashId != null) {
+                if (
+                    branchIdsActive[disp.bi] == true &&
+                    replacesHashId != null
+                ) {
                     dispHashIdsAdded[replacesHashId] = true;
                 }
             }
         }
 
-
         for (const level of levelsOrderedByOrder) {
             for (const layer of layersOrderedByOrder) {
                 // If it's not visible (enabled), continue
-                if (!layer.visible && !isEditorActive)
-                    continue;
+                if (!layer.visible && !isEditorActive) continue;
 
                 for (let gridOrBranch of gridsOrBranchesToCompile) {
                     let gridOrBranchDisps = gridOrBranch.disps;
 
                     // If this is the first iteration, initialise to 0
                     let nextIndex = dispIndexByGridKey[gridOrBranch.key];
-                    if (nextIndex == null)
-                        nextIndex = 0;
+                    if (nextIndex == null) nextIndex = 0;
 
                     // If we've processed all the disps in this grid, continue to next
-                    if (nextIndex >= gridOrBranchDisps.length)
-                        continue;
+                    if (nextIndex >= gridOrBranchDisps.length) continue;
 
                     for (; nextIndex < gridOrBranchDisps.length; nextIndex++) {
                         const disp = gridOrBranchDisps[nextIndex];
 
                         // Filter out overlay disps if we need to
-                        if ((isEditorActive || viewingBranchesActive
-                            || !this.config.model.overlayEnabled)
-                            && DispBase.isOverlay(disp))
+                        if (
+                            (isEditorActive ||
+                                viewingBranchesActive ||
+                                !this.config.model.overlayEnabled) &&
+                            DispBase.isOverlay(disp)
+                        )
                             continue;
 
                         // Level first, as per the sortDisps function
                         let dispLevel = DispBase.level(disp);
-                        if (dispLevel.order < level.order)
-                            continue;
+                        if (dispLevel.order < level.order) continue;
 
-                        if (level.order < dispLevel.order)
-                            break;
+                        if (level.order < dispLevel.order) break;
 
                         // Then Layer
                         let dispLayer = DispBase.layer(disp);
-                        if (dispLayer.order < layer.order)
-                            continue;
+                        if (dispLayer.order < layer.order) continue;
 
-                        if (layer.order < dispLayer.order)
-                            break;
+                        if (layer.order < dispLayer.order) break;
 
                         // If the disp has already been added or is being replaced
                         // by a branch, then skip this one
@@ -389,14 +318,18 @@ export class PeekCanvasModel {
                             continue;
 
                         // Is the branch showed from the "View Branches" menu
-                        let isBranchViewable = branchIdsActive[disp.bi] === true;
+                        let isBranchViewable =
+                            branchIdsActive[disp.bi] === true;
 
                         // If this is not apart of a branch, or ...
-                        if (disp.bi == null || isBranchViewable || gridOrBranch.isBranch) {
+                        if (
+                            disp.bi == null ||
+                            isBranchViewable ||
+                            gridOrBranch.isBranch
+                        ) {
                             disps.push(disp);
                             dispHashIdsAdded[DispBase.hashId(disp)] = true;
                         }
-
                     }
 
                     dispIndexByGridKey[gridOrBranch.key] = nextIndex;
@@ -404,10 +337,11 @@ export class PeekCanvasModel {
             }
         }
 
-        this._override.applyOverridesToModel(disps);
+        for (const override of this._overrides) {
+            override.compile(disps);
+        }
 
-        if (isEditorActive)
-            this.relinkDispGroups(disps);
+        if (isEditorActive) this.relinkDispGroups(disps);
 
         this._visibleDisps = disps;
         this.selection.applyTryToSelect();
@@ -416,13 +350,110 @@ export class PeekCanvasModel {
 
         let timeTaken = now() - startTime;
 
-        console.log(`${dateStr()} Model: compileDisps took ${timeTaken}ms`
-            + ` for ${disps.length} disps`
-            + ` and ${gridsOrBranchesToCompile.length} grids/branches`);
+        console.log(
+            `${dateStr()} Model: compileDisps took ${timeTaken}ms` +
+                ` for ${disps.length} disps` +
+                ` and ${gridsOrBranchesToCompile.length} grids/branches`
+        );
     }
 
-    recompileModel(): void {
-        this._compileDisps(true);
+    // -------------------------------------------------------------------------
+    private reset() {
+        this.needsUpdate = false;
+        this.isUpdating = false;
+
+        this._visibleDisps = []; // Objects to be drawn on the display
+        this._gridBuffer = {}; // Store grids from the server by gridKey.
+
+        this._viewingGridKeysDict = {};
+        this._viewingGridKeysStr = "";
+    }
+
+    // -------------------------------------------------------------------------
+    private _checkGridKeysForArea() {
+        if (this._coordSetId == null) return;
+
+        if (!this.lookupCache.isReady()) return;
+
+        if (!this.needsUpdate) return;
+
+        this.needsUpdate = false;
+
+        let area = this.config.viewPort.window;
+        let zoom = this.config.viewPort.zoom;
+
+        let viewingGridKeys = this.config.controller.coordSet.gridKeysForArea(
+            area,
+            zoom
+        );
+
+        // If there is no change, then do nothing
+        // Should these be sorted?
+        if (viewingGridKeys.join() == this._viewingGridKeysStr) return;
+
+        this._viewingGridKeysStr = viewingGridKeys.join();
+        this._viewingGridKeysDict = dictSetFromArray(viewingGridKeys);
+
+        // Remove grids we're no longer looking at.
+        for (let gridKey of dictKeysFromObject(this._gridBuffer)) {
+            if (!this._viewingGridKeysDict.hasOwnProperty(gridKey)) {
+                delete this._gridBuffer[gridKey];
+            }
+        }
+
+        // Notify the grid manager that the view has changed
+        this.gridObservable.updateDiagramWatchedGrids(
+            this.config.canvasId,
+            viewingGridKeys
+        );
+    }
+
+    // -------------------------------------------------------------------------
+    /** Receive Grid
+     *
+     * NOTE: The grid data is not received in order,
+     * and sometimes the ModelGrids don't have data when no
+     * update from the server is requird.
+     *
+     * @param linkedGrids: A list of grids from the GridObservable
+     * @private
+     */
+    private _receiveGrid(linkedGrids: LinkedGrid[]) {
+        // Overwrite with all the new ones
+        for (let linkedGrid of linkedGrids) {
+            console.log(
+                `PeekCanvasModel: Received grid ${linkedGrid.gridKey},  ${linkedGrid.lastUpdate}`
+            );
+
+            // If the grid now has no data, then clear it from the model.
+            if (!linkedGrid.hasData()) {
+                if (this._gridBuffer[linkedGrid.gridKey] != null) {
+                    console.log(
+                        `PeekCanvasModel: Clearing grid ${linkedGrid.gridKey}`
+                    );
+                    delete this._gridBuffer[linkedGrid.gridKey];
+                    this.needsCompiling = true;
+                }
+                continue;
+            }
+
+            // If we're not viewing this grid any more, discard the data.
+            if (this._viewingGridKeysDict[linkedGrid.gridKey] == null) continue;
+
+            // If it's not an update, also ignore it.
+            let currentGrid = this._gridBuffer[linkedGrid.gridKey];
+            if (
+                currentGrid != null &&
+                currentGrid.lastUpdate == linkedGrid.lastUpdate
+            )
+                continue;
+
+            console.log(
+                `PeekCanvasModel: Applying grid ${linkedGrid.gridKey},  ${linkedGrid.lastUpdate}`
+            );
+            this._gridBuffer[linkedGrid.gridKey] = linkedGrid;
+            this.needsCompiling = true;
+        }
     }
 
     private relinkDispGroups(disps: DispBaseT[]): void {
@@ -431,21 +462,18 @@ export class PeekCanvasModel {
         const allDispsById = {};
         for (const disp of disps) {
             allDispsById[disp.id] = disp;
-            if (DispBase.typeOf(disp) != DispType.groupPointer)
-                continue;
+            if (DispBase.typeOf(disp) != DispType.groupPointer) continue;
 
             dispGroupsById[disp.id] = <DispGroupPointerT>disp;
             (<DispGroupPointerT>disp).disps = [];
         }
 
-
         for (const disp of disps) {
             // Reset all bounds
-            disp.bounds = null;
+            DispBase.setBoundsNull(disp);
 
             const groupId = DispBase.groupId(disp);
-            if (groupId == null)
-                continue;
+            if (groupId == null) continue;
 
             const dispGroup = dispGroupsById[groupId];
             if (dispGroup == null) {
@@ -459,5 +487,4 @@ export class PeekCanvasModel {
             dispGroup.disps.push(disp);
         }
     }
-
 }
