@@ -1,5 +1,4 @@
-import {DispBase, DispBaseT} from "../canvas-shapes/DispBase";
-
+import { DispBase, DispBaseT } from "../canvas-shapes/DispBase";
 
 /** Sort Disps
  *
@@ -16,19 +15,14 @@ import {DispBase, DispBaseT} from "../canvas-shapes/DispBase";
  */
 export function sortDisps(disps: DispBaseT[]): DispBaseT[] {
     function cmp(d1: DispBaseT, d2: DispBaseT): number {
-
         let levelDiff = DispBase.level(d1).order - DispBase.level(d2).order;
-        if (levelDiff != 0)
-            return levelDiff;
+        if (levelDiff != 0) return levelDiff;
 
         let layerDiff = DispBase.layer(d1).order - DispBase.layer(d2).order;
-        if (layerDiff != 0)
-            return layerDiff;
+        if (layerDiff != 0) return layerDiff;
 
         return DispBase.zOrder(d1) - DispBase.zOrder(d2);
     }
 
     return disps.sort(cmp);
-
-
-}
\ No newline at end of file
+}
