@@ -1,28 +1,25 @@
-import {Component, Input, OnInit} from "@angular/core";
-import {ComponentLifecycleEventEmitter} from "@synerty/vortexjs";
-import {PeekCanvasEditor} from "../canvas/PeekCanvasEditor.web";
-import {DiagramCoordSetService} from "@peek/peek_plugin_diagram/DiagramCoordSetService";
-import {BranchDetailTuple, BranchService} from "@peek/peek_plugin_branch";
+import { takeUntil } from "rxjs/operators";
+import { Component, Input, OnInit } from "@angular/core";
+import { NgLifeCycleEvents } from "@synerty/vortexjs";
+import { PeekCanvasEditor } from "../canvas/PeekCanvasEditor.web";
+import { DiagramCoordSetService } from "@peek/peek_plugin_diagram/DiagramCoordSetService";
+import { BranchDetailTuple, BranchService } from "@peek/peek_plugin_branch";
 
-import {PrivateDiagramCoordSetService} from "@peek/peek_plugin_diagram/_private/services/PrivateDiagramCoordSetService";
+import { PrivateDiagramCoordSetService } from "@peek/peek_plugin_diagram/_private/services/PrivateDiagramCoordSetService";
 import {
     PopupEditBranchSelectionArgs,
-    PrivateDiagramBranchService
+    PrivateDiagramBranchService,
 } from "@peek/peek_plugin_diagram/_private/branch/PrivateDiagramBranchService";
 
-import { BalloonMsgService } from "@synerty/peek-plugin-base-js"
-import {UserService} from "@peek/peek_core_user";
-
+import { BalloonMsgService } from "@synerty/peek-plugin-base-js";
+import { UserService } from "@peek/peek_core_user";
 
 @Component({
-    selector: 'pl-diagram-start-edit',
-    templateUrl: 'start-edit.component.web.html',
-    styleUrls: ['start-edit.component.web.scss'],
-    moduleId: module.id
+    selector: "pl-diagram-start-edit",
+    templateUrl: "start-edit.component.web.html",
+    styleUrls: ["start-edit.component.web.scss"],
 })
-export class StartEditComponent extends ComponentLifecycleEventEmitter
-    implements OnInit {
-
+export class StartEditComponent extends NgLifeCycleEvents implements OnInit {
     popupShown: boolean = false;
 
     @Input("coordSetKey")
@@ -33,68 +30,33 @@ export class StartEditComponent extends ComponentLifecycleEventEmitter
 
     @Input("canvasEditor")
     canvasEditor: PeekCanvasEditor;
-
-    private coordSetService: PrivateDiagramCoordSetService;
-
-
     items: BranchDetailTuple[] = [];
-
     NEW_TAB = 0;
     EXISTING_TAB = 1;
     barIndex: number = 0;
-
     selectedBranch: BranchDetailTuple = null;
     newBranch: BranchDetailTuple = new BranchDetailTuple();
+    private coordSetService: PrivateDiagramCoordSetService;
 
-
-    constructor(private branchService: PrivateDiagramBranchService,
-                abstractCoordSetService: DiagramCoordSetService,
-                private globalBranchService: BranchService,
-                private balloonMsg: BalloonMsgService,
-                private userService: UserService) {
+    constructor(
+        private branchService: PrivateDiagramBranchService,
+        abstractCoordSetService: DiagramCoordSetService,
+        private globalBranchService: BranchService,
+        private balloonMsg: BalloonMsgService,
+        private userService: UserService
+    ) {
         super();
 
-        this.coordSetService = <PrivateDiagramCoordSetService>abstractCoordSetService;
+        this.coordSetService = <PrivateDiagramCoordSetService>(
+            abstractCoordSetService
+        );
 
-
-        this.branchService
-            .popupEditBranchSelectionObservable
-            .takeUntil(this.onDestroyEvent)
+        this.branchService.popupEditBranchSelectionObservable
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((v: PopupEditBranchSelectionArgs) => this.openPopup(v));
-
     }
 
-    ngOnInit() {
-
-    }
-
-    protected openPopup({coordSetKey, modelSetKey}) {
-        const userDetail = this.userService.userDetails;
-
-        this.newBranch = new BranchDetailTuple();
-        this.newBranch.modelSetKey = this.modelSetKey;
-        this.newBranch.createdDate = new Date();
-        this.newBranch.updatedDate = new Date();
-        this.newBranch.userName = userDetail.userName;
-
-        // let coordSet = this.coordSetService.coordSetForKey(coordSetKey);
-        console.log("Opening Start Edit popup");
-
-        this.globalBranchService.branches(this.modelSetKey)
-            .then((tuples: BranchDetailTuple[]) => {
-                this.items = tuples
-                    .sort((a, b) => b.createdDate.getTime() - a.createdDate.getTime());
-            })
-            .catch((e) => `Failed to load branches ${e}`);
-
-        this.items = [];
-
-        this.popupShown = true;
-    }
-
-
-    // --------------------
-    //
+    ngOnInit() {}
 
     closePopup(): void {
         this.popupShown = false;
@@ -103,12 +65,19 @@ export class StartEditComponent extends ComponentLifecycleEventEmitter
         this.items = [];
     }
 
+    // --------------------
+    //
+
     noItems(): boolean {
         return this.items.length == 0;
     }
 
     isBranchSelected(item: BranchDetailTuple): boolean {
-        return item != null && this.selectedBranch != null && item.id == this.selectedBranch.id;
+        return (
+            item != null &&
+            this.selectedBranch != null &&
+            item.id == this.selectedBranch.id
+        );
     }
 
     selectBranch(item: BranchDetailTuple): void {
@@ -121,17 +90,21 @@ export class StartEditComponent extends ComponentLifecycleEventEmitter
         if (this.barIndex == this.NEW_TAB) {
             let nb = this.newBranch;
             if (nb.name == null || nb.name.length == 0) {
-                this.balloonMsg.showWarning("Name must be supplied to create a branch");
+                this.balloonMsg.showWarning(
+                    "Name must be supplied to create a branch"
+                );
                 return;
             }
 
             nb.key = `${nb.userName}|${nb.createdDate.getTime()}|${nb.name}`;
 
-            this.globalBranchService.createBranch(nb)
-                .catch(e => this.balloonMsg.showError(`Failed to create branch : ${e}`));
+            this.globalBranchService
+                .createBranch(nb)
+                .catch((e) =>
+                    this.balloonMsg.showError(`Failed to create branch : ${e}`)
+                );
 
             branchToEdit = this.newBranch;
-
         } else if (this.barIndex == this.EXISTING_TAB) {
             if (this.selectedBranch == null) {
                 this.balloonMsg.showWarning("You must select a branch to edit");
@@ -139,14 +112,39 @@ export class StartEditComponent extends ComponentLifecycleEventEmitter
             }
 
             branchToEdit = this.selectedBranch;
-
         }
 
         this.branchService.startEditing(
-            this.modelSetKey, this.coordSetKey, branchToEdit.key
+            this.modelSetKey,
+            this.coordSetKey,
+            branchToEdit.key
         );
         this.closePopup();
     }
 
+    protected openPopup({ coordSetKey, modelSetKey }) {
+        const userDetail = this.userService.userDetails;
 
+        this.newBranch = new BranchDetailTuple();
+        this.newBranch.modelSetKey = this.modelSetKey;
+        this.newBranch.createdDate = new Date();
+        this.newBranch.updatedDate = new Date();
+        this.newBranch.userName = userDetail.userName;
+
+        // let coordSet = this.coordSetService.coordSetForKey(coordSetKey);
+        console.log("Opening Start Edit popup");
+
+        this.globalBranchService
+            .branches(this.modelSetKey)
+            .then((tuples: BranchDetailTuple[]) => {
+                this.items = tuples.sort(
+                    (a, b) => b.createdDate.getTime() - a.createdDate.getTime()
+                );
+            })
+            .catch((e) => `Failed to load branches ${e}`);
+
+        this.items = [];
+
+        this.popupShown = true;
+    }
 }
