@@ -1,18 +1,21 @@
 import logging
 from typing import Dict
 
-from peek_abstract_chunked_index.private.client.handlers.ACICacheHandlerABC import \
-    ACICacheHandlerABC
-from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import \
-    ACIUpdateDateTupleABC
+from peek_abstract_chunked_index.private.client.handlers.ACICacheHandlerABC import (
+    ACICacheHandlerABC,
+)
+from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import (
+    ACIUpdateDateTupleABC,
+)
 from peek_plugin_diagram._private.PluginNames import diagramFilt
-from peek_plugin_diagram._private.tuples.branch.BranchIndexUpdateDateTuple import \
-    BranchIndexUpdateDateTuple
+from peek_plugin_diagram._private.tuples.branch.BranchIndexUpdateDateTuple import (
+    BranchIndexUpdateDateTuple,
+)
 
 logger = logging.getLogger(__name__)
 
 clientBranchIndexWatchUpdateFromDeviceFilt = {
-    'key': "clientBranchIndexWatchUpdateFromDevice"
+    "key": "clientBranchIndexWatchUpdateFromDevice"
 }
 clientBranchIndexWatchUpdateFromDeviceFilt.update(diagramFilt)
 
