@@ -3,7 +3,9 @@ from collections import defaultdict
 from datetime import datetime
 from typing import List, Dict
 
-from peek_plugin_diagram._private.tuples.grid.EncodedGridTuple import EncodedGridTuple
+from peek_plugin_diagram._private.tuples.grid.EncodedGridTuple import (
+    EncodedGridTuple,
+)
 from twisted.internet.defer import DeferredList, Deferred, inlineCallbacks
 from vortex.DeferUtil import vortexLogFailure
 from vortex.Payload import Payload
@@ -11,20 +13,26 @@ from vortex.PayloadEnvelope import PayloadEnvelope
 from vortex.VortexABC import SendVortexMsgResponseCallable
 from vortex.VortexFactory import VortexFactory
 
-from peek_abstract_chunked_index.private.client.handlers.ACICacheHandlerABC import \
-    ACICacheHandlerABC
-from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import \
-    ACIUpdateDateTupleABC
+from peek_abstract_chunked_index.private.client.handlers.ACICacheHandlerABC import (
+    ACICacheHandlerABC,
+)
+from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import (
+    ACIUpdateDateTupleABC,
+)
 from peek_plugin_diagram._private.PluginNames import diagramFilt
-from peek_plugin_diagram._private.client.controller.GridCacheController import \
-    GridCacheController
-from peek_plugin_diagram._private.server.client_handlers.ClientGridLoaderRpc import \
-    ClientGridLoaderRpc
-from peek_plugin_diagram._private.storage.GridKeyIndex import GridKeyIndexCompiled
+from peek_plugin_diagram._private.client.controller.GridCacheController import (
+    GridCacheController,
+)
+from peek_plugin_diagram._private.server.client_handlers.ClientGridLoaderRpc import (
+    ClientGridLoaderRpc,
+)
+from peek_plugin_diagram._private.storage.GridKeyIndex import (
+    GridKeyIndexCompiled,
+)
 
 logger = logging.getLogger(__name__)
 
-clientGridWatchUpdateFromDeviceFilt = {'key': "clientGridWatchUpdateFromDevice"}
+clientGridWatchUpdateFromDeviceFilt = {"key": "clientGridWatchUpdateFromDevice"}
 clientGridWatchUpdateFromDeviceFilt.update(diagramFilt)
 
 #: This the type of the data that we get when the clients observe new grids.
@@ -38,9 +46,10 @@ class GridCacheHandler(ACICacheHandlerABC):
     _logger: logging.Logger = logger
 
     def __init__(self, cacheController: GridCacheController, clientId: str):
-        """ App Grid Handler
+        """App Grid Handler
 
-        This class handles the custom needs of the desktop/mobile apps observing grids.
+        This class handles the custom needs of the desktop/mobile
+         apps observing grids.
 
         """
         ACICacheHandlerABC.__init__(self, cacheController, clientId)
@@ -61,7 +70,9 @@ class GridCacheHandler(ACICacheHandlerABC):
         # Which is incomplete at this point :-|
 
         vortexUuids = set(VortexFactory.getRemoteVortexUuids())
-        vortexUuidsToRemove = set(self._observedGridKeysByVortexUuid) - vortexUuids
+        vortexUuidsToRemove = (
+            set(self._observedGridKeysByVortexUuid) - vortexUuids
+        )
 
         if not vortexUuidsToRemove:
             return
@@ -75,7 +86,7 @@ class GridCacheHandler(ACICacheHandlerABC):
     # Process update from the server
 
     def notifyOfUpdate(self, gridKeys: List[str]):
-        """ Notify of Grid Updates
+        """Notify of Grid Updates
 
         This method is called by the client.GridCacheController when it receives updates
         from the server.
@@ -96,8 +107,11 @@ class GridCacheHandler(ACICacheHandlerABC):
 
             # Queue up the required client notifications
             for vortexUuid in vortexUuids:
-                logger.debug("Sending unsolicited grid %s to vortex %s",
-                             gridKey, vortexUuid)
+                logger.debug(
+                    "Sending unsolicited grid %s to vortex %s",
+                    gridKey,
+                    vortexUuid,
+                )
                 payloadsByVortexUuid[vortexUuid].tuples.append(gridTuple)
 
         # Send the updates to the clients
@@ -107,8 +121,12 @@ class GridCacheHandler(ACICacheHandlerABC):
 
             # Serliase in thread, and then send.
             d = payload.makePayloadEnvelopeDefer()
-            d.addCallback(lambda payloadEnvelope: payloadEnvelope.toVortexMsgDefer())
-            d.addCallback(VortexFactory.sendVortexMsg, destVortexUuid=vortexUuid)
+            d.addCallback(
+                lambda payloadEnvelope: payloadEnvelope.toVortexMsgDefer()
+            )
+            d.addCallback(
+                VortexFactory.sendVortexMsg, destVortexUuid=vortexUuid
+            )
             dl.append(d)
 
         # Log the errors, otherwise we don't care about them
@@ -119,10 +137,13 @@ class GridCacheHandler(ACICacheHandlerABC):
     # Process observes from the devices
 
     @inlineCallbacks
-    def _processObserve(self, payloadEnvelope: PayloadEnvelope,
-                        vortexUuid: str,
-                        sendResponse: SendVortexMsgResponseCallable,
-                        **kwargs):
+    def _processObserve(
+        self,
+        payloadEnvelope: PayloadEnvelope,
+        vortexUuid: str,
+        sendResponse: SendVortexMsgResponseCallable,
+        **kwargs
+    ):
         cacheAll = payloadEnvelope.filt.get("cacheAll") == True
 
         payload = yield payloadEnvelope.decodePayloadDefer()
@@ -134,13 +155,12 @@ class GridCacheHandler(ACICacheHandlerABC):
             self._observedGridKeysByVortexUuid[vortexUuid] = gridKeys
             self._rebuildStructs()
 
-        self._replyToObserve(payload.filt,
-                             lastUpdateByGridKey,
-                             sendResponse,
-                             cacheAll=cacheAll)
+        self._replyToObserve(
+            payload.filt, lastUpdateByGridKey, sendResponse, cacheAll=cacheAll
+        )
 
     def _rebuildStructs(self) -> None:
-        """ Rebuild Structs
+        """Rebuild Structs
 
         Rebuild the reverse index of uuids by grid key.
 
@@ -161,18 +181,21 @@ class GridCacheHandler(ACICacheHandlerABC):
         if keysChanged:
             d = ClientGridLoaderRpc.updateClientWatchedGrids(
                 clientId=self._clientId,
-                gridKeys=list(self._observedVortexUuidsByGridKey)
+                gridKeys=list(self._observedVortexUuidsByGridKey),
             )
             d.addErrback(vortexLogFailure, logger, consumeError=False)
 
     # ---------------
     # Reply to device observe
 
-    def _replyToObserve(self, filt,
-                        lastUpdateByGridKey: DeviceGridT,
-                        sendResponse: SendVortexMsgResponseCallable,
-                        cacheAll=False) -> None:
-        """ Reply to Observe
+    def _replyToObserve(
+        self,
+        filt,
+        lastUpdateByGridKey: DeviceGridT,
+        sendResponse: SendVortexMsgResponseCallable,
+        cacheAll=False,
+    ) -> None:
+        """Reply to Observe
 
         The client has told us that it's observing a new set of grids, and the lastUpdate
         it has for each of those grids. We will send them the grids that are out of date
@@ -190,9 +213,8 @@ class GridCacheHandler(ACICacheHandlerABC):
             if not toSend and not cacheAll:
                 return
 
-            payload = Payload(filt=filt, tuples=toSend)
-            d: Deferred = payload.makePayloadEnvelopeDefer(compressionLevel=2)
-            d.addCallback(lambda payloadEnvelope: payloadEnvelope.toVortexMsgDefer())
+            payloadEnvelope = PayloadEnvelope(filt=filt, data=toSend)
+            d: Deferred = payloadEnvelope.toVortexMsgDefer(base64Encode=False)
             d.addCallback(sendResponse)
             d.addErrback(vortexLogFailure, logger, consumeError=True)
 
@@ -208,14 +230,20 @@ class GridCacheHandler(ACICacheHandlerABC):
                 gridTuple.lastUpdate = lastUpdate
                 gridTuple.encodedGridTuple = None
                 gridTuplesToSend.append(gridTuple)
-                logger.debug("Grid %s is no loner in the cache, %s", gridKey, lastUpdate)
+                logger.debug(
+                    "Grid %s is no loner in the cache, %s", gridKey, lastUpdate
+                )
 
             elif gridTuple.lastUpdate == lastUpdate:
-                logger.debug("Grid %s matches the cache, %s", gridKey, lastUpdate)
+                logger.debug(
+                    "Grid %s matches the cache, %s", gridKey, lastUpdate
+                )
 
             else:
                 gridTuplesToSend.append(gridTuple)
-                logger.debug("Sending grid %s from the cache, %s" , gridKey, lastUpdate)
+                logger.debug(
+                    "Sending grid %s from the cache, %s", gridKey, lastUpdate
+                )
 
             if len(gridTuplesToSend) == 5 and not cacheAll:
                 sendChunk(gridTuplesToSend)
