@@ -3,8 +3,9 @@ from typing import Union
 
 from twisted.internet.defer import Deferred, inlineCallbacks
 
-from peek_plugin_diagram._private.client.controller.ModelSetCacheController import \
-    ModelSetCacheController
+from peek_plugin_diagram._private.client.controller.ModelSetCacheController import (
+    ModelSetCacheController,
+)
 from vortex.Payload import Payload
 from vortex.TupleSelector import TupleSelector
 from vortex.handler.TupleDataObservableHandler import TuplesProviderABC
@@ -17,8 +18,9 @@ class ClientModelSetTupleProvider(TuplesProviderABC):
         self.modelSetCacheController = modelSetCacheController
 
     @inlineCallbacks
-    def makeVortexMsg(self, filt: dict,
-                      tupleSelector: TupleSelector) -> Union[Deferred, bytes]:
+    def makeVortexMsg(
+        self, filt: dict, tupleSelector: TupleSelector
+    ) -> Union[Deferred, bytes]:
         tuples = self.modelSetCacheController.modelSets
 
         payloadEnvelope = yield Payload(filt, tuples=tuples).makePayloadEnvelopeDefer()
