@@ -1,18 +1,34 @@
 import logging
 from typing import List
 
-from peek_abstract_chunked_index.private.server.controller.ACIProcessorQueueControllerABC import \
-    ACIProcessorQueueControllerABC, ACIProcessorQueueBlockItem
-from peek_abstract_chunked_index.private.server.controller.ACIProcessorStatusNotifierABC import \
-    ACIProcessorStatusNotifierABC
-from peek_abstract_chunked_index.private.tuples.ACIProcessorQueueTupleABC import \
-    ACIProcessorQueueTupleABC
-from peek_plugin_diagram._private.server.controller.StatusController import \
-    StatusController
-from peek_plugin_diagram._private.storage.DispIndex import \
-    DispIndexerQueue as DispIndexerQueueTable
-from peek_plugin_diagram._private.storage.Display import DispBase, DispNull, DispGroup, \
-    DispPolyline, DispGroupPointer, DispPolygon, DispEdgeTemplate, DispText, DispEllipse
+from peek_abstract_chunked_index.private.server.controller.ACIProcessorQueueControllerABC import (
+    ACIProcessorQueueControllerABC,
+    ACIProcessorQueueBlockItem,
+)
+from peek_abstract_chunked_index.private.server.controller.ACIProcessorStatusNotifierABC import (
+    ACIProcessorStatusNotifierABC,
+)
+from peek_abstract_chunked_index.private.tuples.ACIProcessorQueueTupleABC import (
+    ACIProcessorQueueTupleABC,
+)
+from peek_plugin_diagram._private.server.controller.StatusController import (
+    StatusController,
+)
+from peek_plugin_diagram._private.storage.DispIndex import (
+    DispIndexerQueue as DispIndexerQueueTable,
+)
+from peek_plugin_diagram._private.storage.Display import (
+    DispBase,
+    DispNull,
+    DispGroup,
+    DispPolyline,
+    DispGroupPointer,
+    DispPolygon,
+    DispEdgeTemplate,
+    DispText,
+    DispEllipse,
+)
+from peek_plugin_diagram._private.storage.Display import DispCurvedText
 from peek_plugin_diagram._private.storage.LiveDbDispLink import LiveDbDispLink
 from vortex.DeferUtil import deferToThreadWrapWithLogger
 
@@ -29,7 +45,9 @@ class _Notifier(ACIProcessorStatusNotifierABC):
         self._adminStatusController.notify()
 
     def addToProcessorTotal(self, delta: int):
-        self._adminStatusController.status.displayCompilerProcessedTotal += delta
+        self._adminStatusController.status.displayCompilerProcessedTotal += (
+            delta
+        )
         self._adminStatusController.notify()
 
     def setProcessorError(self, error: str):
@@ -51,18 +69,30 @@ class DispCompilerQueueController(ACIProcessorQueueControllerABC):
 
     _logger = logger
     _QueueDeclarative: ACIProcessorQueueTupleABC = DispIndexerQueueTable
-    _VacuumDeclaratives = (DispIndexerQueueTable,
-                           DispBase, DispNull, DispText, DispPolygon, DispPolyline,
-                           DispEllipse, DispGroup, DispEdgeTemplate, DispGroupPointer,
-                           LiveDbDispLink)
+    _VacuumDeclaratives = (
+        DispIndexerQueueTable,
+        DispBase,
+        DispNull,
+        DispText,
+        DispCurvedText,
+        DispPolygon,
+        DispPolyline,
+        DispEllipse,
+        DispGroup,
+        DispEdgeTemplate,
+        DispGroupPointer,
+        LiveDbDispLink,
+    )
 
     def __init__(self, dbSessionCreator, statusController: StatusController):
-        ACIProcessorQueueControllerABC.__init__(self, dbSessionCreator,
-                                                _Notifier(statusController))
+        ACIProcessorQueueControllerABC.__init__(
+            self, dbSessionCreator, _Notifier(statusController)
+        )
 
     def _sendToWorker(self, block: ACIProcessorQueueBlockItem):
-        from peek_plugin_diagram._private.worker.tasks.DispCompilerTask import \
-            compileDisps
+        from peek_plugin_diagram._private.worker.tasks.DispCompilerTask import (
+            compileDisps,
+        )
 
         return compileDisps.delay(block.itemsEncodedPayload)
 
@@ -73,7 +103,7 @@ class DispCompilerQueueController(ACIProcessorQueueControllerABC):
     # Deduplicate methods
 
     def _dedupeQueueSql(self, lastFetchedId: int, dedupeLimit: int):
-        return '''
+        return """
                  with sq_raw as (
                     SELECT "id", "dispId"
                     FROM pl_diagram."DispCompilerQueue"
@@ -92,7 +122,10 @@ class DispCompilerQueueController(ACIProcessorQueueControllerABC):
                     AND pl_diagram."DispCompilerQueue"."id" > %(id)s
                     AND pl_diagram."DispCompilerQueue"."dispId" = sq1."dispId"
 
-            ''' % {'id': lastFetchedId, 'limit': dedupeLimit}
+            """ % {
+            "id": lastFetchedId,
+            "limit": dedupeLimit,
+        }
 
     # ---------------
     # Insert into Queue methods
@@ -102,7 +135,9 @@ class DispCompilerQueueController(ACIProcessorQueueControllerABC):
         return self.queueDispIdsToCompile(dispIds, self._dbSessionCreator)
 
     @classmethod
-    def queueDispIdsToCompile(cls, dispIdsToCompile: List[int], dbSessionCreator):
+    def queueDispIdsToCompile(
+        cls, dispIdsToCompile: List[int], dbSessionCreator
+    ):
         if not dispIdsToCompile:
             return
 
@@ -115,7 +150,9 @@ class DispCompilerQueueController(ACIProcessorQueueControllerABC):
             ormSession.close()
 
     @staticmethod
-    def queueDispIdsToCompileWithSession(dispIdsToCompile: List[int], ormSessionOrConn):
+    def queueDispIdsToCompileWithSession(
+        dispIdsToCompile: List[int], ormSessionOrConn
+    ):
         if not dispIdsToCompile:
             return
 
@@ -125,4 +162,6 @@ class DispCompilerQueueController(ACIProcessorQueueControllerABC):
         for dispId in dispIdsToCompile:
             inserts.append(dict(dispId=dispId))
 
-        ormSessionOrConn.execute(DispIndexerQueueTable.__table__.insert(), inserts)
+        ormSessionOrConn.execute(
+            DispIndexerQueueTable.__table__.insert(), inserts
+        )
