@@ -1,15 +1,16 @@
 from datetime import datetime
 
 from peek_plugin_diagram._private.PluginNames import diagramTuplePrefix
-from peek_plugin_diagram._private.tuples.branch.BranchLiveEditTupleAction import \
-    BranchLiveEditTupleAction
+from peek_plugin_diagram._private.tuples.branch.BranchLiveEditTupleAction import (
+    BranchLiveEditTupleAction,
+)
 from peek_plugin_diagram._private.tuples.branch.BranchTuple import BranchTuple
 from vortex.Tuple import Tuple, addTupleType, TupleField
 
 
 @addTupleType
 class BranchLiveEditTuple(Tuple):
-    """ Branch Live Edit Tuple
+    """Branch Live Edit Tuple
 
     This tuple is used internally to transfer branches between UIs that are actively
     editing the.
@@ -17,7 +18,8 @@ class BranchLiveEditTuple(Tuple):
     This isn't stored anywhere, it just gets relayed between multiple UIs.
 
     """
-    __tupleType__ = diagramTuplePrefix + 'BranchLiveEditTuple'
+
+    __tupleType__ = diagramTuplePrefix + "BranchLiveEditTuple"
 
     EDITING_STARTED = BranchLiveEditTupleAction.EDITING_STARTED
     EDITING_UPDATED = BranchLiveEditTupleAction.EDITING_UPDATED
@@ -31,4 +33,4 @@ class BranchLiveEditTuple(Tuple):
     uiUpdateDate: datetime = TupleField()
     serverUpdateDate: datetime = TupleField()
 
-    updateFromActionType: int = TupleField()
\ No newline at end of file
+    updateFromActionType: int = TupleField()
