@@ -1,4 +1,4 @@
-export let diagramFilt = {"plugin": "peek_plugin_diagram"};
+export let diagramFilt = { plugin: "peek_plugin_diagram" };
 export let diagramTuplePrefix = "peek_plugin_diagram.";
 
 export let diagramObservableName = "peek_plugin_diagram";
@@ -13,5 +13,4 @@ export let locationIndexCacheStorageName = "peek_plugin_diagram_location_index";
 
 export let branchLocalStorageName = "peek_plugin_diagram_branch_local";
 
-
-export let diagramPluginName = "peek_plugin_diagram";
\ No newline at end of file
+export let diagramPluginName = "peek_plugin_diagram";
