@@ -1,4 +1,6 @@
-import {Injectable} from "@angular/core";
+import { Observable, Subject } from "rxjs";
+import { filter, first, takeUntil } from "rxjs/operators";
+import { Injectable } from "@angular/core";
 
 import {
     extend,
@@ -7,36 +9,41 @@ import {
     TupleOfflineStorageNameService,
     TupleOfflineStorageService,
     TupleSelector,
+    TupleStorageBatchSaveArguments,
     TupleStorageFactoryService,
     VortexService,
-    VortexStatusService
+    VortexStatusService,
 } from "@synerty/vortexjs";
 
-import {branchIndexStorageName, diagramFilt, diagramTuplePrefix} from "../PluginNames";
-
-
-import {Subject} from "rxjs/Subject";
-import {Observable} from "rxjs/Observable";
-import {BranchIndexEncodedChunkTuple} from "./BranchIndexEncodedChunkTuple";
-import {BranchIndexUpdateDateTuple} from "./BranchIndexUpdateDateTuple";
-import {BranchTuple} from "../branch/BranchTuple";
-import {PrivateDiagramTupleService} from "../services/PrivateDiagramTupleService";
-import {BranchIndexLoaderStatusTuple} from "./BranchIndexLoaderStatusTuple";
-
-import {OfflineConfigTuple} from "../tuples/OfflineConfigTuple";
-import {ModelSet} from "../tuples/ModelSet";
-import {BranchIndexLoaderServiceA} from "./BranchIndexLoaderServiceA";
+import {
+    branchIndexStorageName,
+    diagramFilt,
+    diagramTuplePrefix,
+} from "../PluginNames";
+import { BranchIndexEncodedChunkTuple } from "./BranchIndexEncodedChunkTuple";
+import { BranchIndexUpdateDateTuple } from "./BranchIndexUpdateDateTuple";
+import { BranchTuple } from "../branch/BranchTuple";
+import { PrivateDiagramTupleService } from "../services/PrivateDiagramTupleService";
+import { BranchIndexLoaderStatusTuple } from "./BranchIndexLoaderStatusTuple";
+import { ModelSet } from "../tuples/ModelSet";
+import { BranchIndexLoaderServiceA } from "./BranchIndexLoaderServiceA";
+import {
+    DeviceOfflineCacheService,
+    OfflineCacheStatusTuple,
+} from "@peek/peek_core_device";
+import { EncodedGridTuple } from "@peek/peek_plugin_diagram/_private/grid-loader/EncodedGridTuple";
+import { EncodedLocationIndexTuple } from "@peek/peek_plugin_diagram/_private/location-loader/EncodedLocationIndexTuple";
 
 // ----------------------------------------------------------------------------
 
 export interface BranchIndexResultI {
-    [key: string]: BranchTuple[]
+    [key: string]: BranchTuple[];
 }
 
 // ----------------------------------------------------------------------------
 
 let clientBranchIndexWatchUpdateFromDeviceFilt = extend(
-    {'key': "clientBranchIndexWatchUpdateFromDevice"},
+    { key: "clientBranchIndexWatchUpdateFromDevice" },
     diagramFilt
 );
 
@@ -49,9 +56,8 @@ const cacheAll = "cacheAll";
  */
 
 class BranchIndexChunkTupleSelector extends TupleSelector {
-
     constructor(private chunkKey: string) {
-        super(diagramTuplePrefix + "BranchIndexChunkTuple", {key: chunkKey});
+        super(diagramTuplePrefix + "BranchIndexChunkTuple", { key: chunkKey });
     }
 
     toOrderedJsonStr(): string {
@@ -70,7 +76,6 @@ class UpdateDateTupleSelector extends TupleSelector {
     }
 }
 
-
 // ----------------------------------------------------------------------------
 /** hash method
  */
@@ -78,17 +83,17 @@ let BUCKET_COUNT = 8192;
 
 function keyChunk(modelSetKey: string, key: string): string {
     /** Object ID Chunk
-
+     
      This method creates an int from 0 to MAX, representing the hash bucket for this
      object Id.
-
+     
      This is simple, and provides a reasonable distribution
-
+     
      @param modelSetKey: The key of the model set that the branchIndexs are in
      @param key: The key of the branchIndex to get the chunk key for
-
+     
      @return: The bucket / chunkKey where you'll find the object with this ID
-
+     
      */
     if (key == null || key.length == 0)
         throw new Error("key is None or zero length");
@@ -96,7 +101,7 @@ function keyChunk(modelSetKey: string, key: string): string {
     let bucket = 0;
 
     for (let i = 0; i < key.length; i++) {
-        bucket = ((bucket << 5) - bucket) + key.charCodeAt(i);
+        bucket = (bucket << 5) - bucket + key.charCodeAt(i);
         bucket |= 0; // Convert to 32bit integer
     }
 
@@ -105,7 +110,6 @@ function keyChunk(modelSetKey: string, key: string): string {
     return `${modelSetKey}.${bucket}`;
 }
 
-
 // ----------------------------------------------------------------------------
 /** BranchIndex Cache
  *
@@ -118,9 +122,13 @@ function keyChunk(modelSetKey: string, key: string): string {
  */
 @Injectable()
 export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
-
     private UPDATE_CHUNK_FETCH_SIZE = 5;
-    private OFFLINE_CHECK_PERIOD_MS = 15 * 60 * 1000; // 15 minutes
+
+    // Every 100 chunks from the server
+    private SAVE_POINT_ITERATIONS = 100;
+
+    // Saving the cache after each chunk is so expensive, we only do it every 20 or so
+    private chunksSavedSinceLastIndexSave = 0;
 
     private index = new BranchIndexUpdateDateTuple();
     private askServerChunks: BranchIndexUpdateDateTuple[] = [];
@@ -136,31 +144,19 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
     private modelSetByIds: { [id: number]: ModelSet } = {};
     private _hasModelSetLoaded = false;
 
-    private offlineConfig: OfflineConfigTuple = new OfflineConfigTuple();
-
-
-    constructor(private vortexService: VortexService,
-                private vortexStatusService: VortexStatusService,
-                storageFactory: TupleStorageFactoryService,
-                private tupleService: PrivateDiagramTupleService) {
+    constructor(
+        private vortexService: VortexService,
+        private vortexStatusService: VortexStatusService,
+        storageFactory: TupleStorageFactoryService,
+        private tupleService: PrivateDiagramTupleService,
+        private deviceCacheControllerService: DeviceOfflineCacheService
+    ) {
         super();
 
-        this.tupleService.offlineObserver
-            .subscribeToTupleSelector(new TupleSelector(OfflineConfigTuple.tupleName, {}),
-                false, false, true)
-            .takeUntil(this.onDestroyEvent)
-            .filter(v => v.length != 0)
-            .subscribe((tuples: OfflineConfigTuple[]) => {
-                this.offlineConfig = tuples[0];
-                if (this.offlineConfig.cacheChunksForOffline)
-                    this.initialLoad();
-                this._notifyStatus();
-            });
-
         let modelSetTs = new TupleSelector(ModelSet.tupleName, {});
         this.tupleService.offlineObserver
             .subscribeToTupleSelector(modelSetTs)
-            .takeUntil(this.onDestroyEvent)
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((tuples: ModelSet[]) => {
                 this.modelSetByIds = {};
                 for (let item of tuples) {
@@ -178,10 +174,13 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
         this.setupVortexSubscriptions();
         this._notifyStatus();
 
-        // Check for updates every so often
-        Observable.interval(this.OFFLINE_CHECK_PERIOD_MS)
-            .takeUntil(this.onDestroyEvent)
-            .subscribe(() => this.askServerForUpdates());
+        this.deviceCacheControllerService.triggerCachingObservable
+            .pipe(takeUntil(this.onDestroyEvent))
+            .pipe(filter((v) => v))
+            .subscribe(() => {
+                this.initialLoad();
+                this._notifyStatus();
+            });
     }
 
     isReady(): boolean {
@@ -192,7 +191,6 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
         return this._hasLoadedSubject;
     }
 
-
     statusObservable(): Observable<BranchIndexLoaderStatusTuple> {
         return this._statusSubject;
     }
@@ -201,20 +199,98 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
         return this._status;
     }
 
+    /** Get BranchIndexs
+     *
+     * Get the objects with matching keywords from the index..
+     *
+     * @param: modelSetKey: The model set that the branches live in
+     * @param: coordSetId: Get the branch that lives in this coordSet, or null to return
+     *          branches living in all coord sets.
+     * @param: keys: The keys to load the branches for.
+     *
+     */
+    getBranches(
+        modelSetKey: string,
+        coordSetId: number | null,
+        keys: string[]
+    ): Promise<BranchIndexResultI> {
+        if (modelSetKey == null || modelSetKey.length == 0) {
+            Promise.reject("We've been passed a null/empty modelSetKey");
+        }
+
+        if (keys == null || keys.length == 0) {
+            Promise.reject("We've been passed a null/empty keys");
+        }
+
+        // If there is no offline support, or we're online
+        if (
+            !this.deviceCacheControllerService.offlineModeEnabled ||
+            this.vortexStatusService.snapshot.isOnline
+        ) {
+            let ts = new TupleSelector(BranchTuple.tupleName, {
+                modelSetKey: modelSetKey,
+                coordSetId: coordSetId,
+                keys: keys,
+            });
+
+            let isOnlinePromise: any = this.vortexStatusService.snapshot
+                .isOnline
+                ? Promise.resolve()
+                : this.vortexStatusService.isOnline
+                      .pipe(filter((online) => online))
+                      .pipe(first())
+                      .toPromise();
+
+            return isOnlinePromise
+                .then(() =>
+                    this.tupleService.offlineObserver.pollForTuples(ts, false)
+                )
+                .then((docs: BranchTuple[]) =>
+                    this._populateAndIndexObjectTypes(docs)
+                );
+        }
+
+        // If we do have offline support
+        if (this.isReady())
+            return this.getChunksWhenReady(modelSetKey, coordSetId, keys) //
+                .then((docs) => this._populateAndIndexObjectTypes(docs));
+
+        return this.isReadyObservable()
+            .pipe(first((ready) => ready))
+            .pipe(first())
+            .toPromise()
+            .then(() => this.getChunksWhenReady(modelSetKey, coordSetId, keys))
+            .then((docs) => this._populateAndIndexObjectTypes(docs));
+    }
+
     private _notifyReady(): void {
         if (this._hasModelSetLoaded && this._hasLoaded)
             this._hasLoadedSubject.next();
     }
 
     private _notifyStatus(): void {
-        this._status.cacheForOfflineEnabled = this.offlineConfig.cacheChunksForOffline;
+        this._status.cacheForOfflineEnabled =
+            this.deviceCacheControllerService.cachingEnabled;
         this._status.initialLoadComplete = this.index.initialLoadComplete;
 
-        this._status.loadProgress = Object.keys(this.index.updateDateByChunkKey).length;
+        this._status.loadProgress = Object.keys(
+            this.index.updateDateByChunkKey
+        ).length;
         for (let chunk of this.askServerChunks)
-            this._status.loadProgress -= Object.keys(chunk.updateDateByChunkKey).length;
+            this._status.loadProgress -= Object.keys(
+                chunk.updateDateByChunkKey
+            ).length;
 
         this._statusSubject.next(this._status);
+
+        const status = new OfflineCacheStatusTuple();
+        status.pluginName = "peek_plugin_diagram";
+        status.indexName = "Branch Index";
+        status.loadingQueueCount = this._status.loadProgress;
+        status.totalLoadedCount = this._status.loadTotal;
+        status.lastCheckDate = new Date();
+        status.initialFullLoadComplete = this._status.initialLoadComplete;
+        this.deviceCacheControllerService.updateCachingStatus(status);
     }
 
     /** Initial load
@@ -222,8 +298,8 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
      * Load the dates of the index buckets and ask the server if it has any updates.
      */
     private initialLoad(): void {
-
-        this.storage.loadTuples(new UpdateDateTupleSelector())
+        this.storage
+            .loadTuples(new UpdateDateTupleSelector())
             .then((tuplesAny: any[]) => {
                 let tuples: BranchIndexUpdateDateTuple[] = tuplesAny;
                 if (tuples.length != 0) {
@@ -233,7 +309,6 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
                         this._hasLoaded = true;
                         this._notifyReady();
                     }
-
                 }
 
                 this.askServerForUpdates();
@@ -244,28 +319,31 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
     }
 
     private setupVortexSubscriptions(): void {
-
         // Services don't have destructors, I'm not sure how to unsubscribe.
-        this.vortexService.createEndpointObservable(this, clientBranchIndexWatchUpdateFromDeviceFilt)
-            .takeUntil(this.onDestroyEvent)
+        this.vortexService
+            .createEndpointObservable(
+                this,
+                clientBranchIndexWatchUpdateFromDeviceFilt
+            )
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((payloadEnvelope: PayloadEnvelope) => {
-                this.processBranchIndexsFromServer(payloadEnvelope);
+                this.processChunksFromServer(payloadEnvelope);
             });
 
         // If the vortex service comes back online, update the watch grids.
         this.vortexStatusService.isOnline
-            .filter(isOnline => isOnline == true)
-            .takeUntil(this.onDestroyEvent)
+            .pipe(filter((isOnline) => isOnline == true))
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe(() => this.askServerForUpdates());
-
     }
 
     private areWeTalkingToTheServer(): boolean {
-        return this.offlineConfig.cacheChunksForOffline
-            && this.vortexStatusService.snapshot.isOnline;
+        return (
+            this.deviceCacheControllerService.offlineModeEnabled &&
+            this.vortexStatusService.snapshot.isOnline
+        );
     }
 
-
     /** Ask Server For Updates
      *
      * Tell the server the state of the chunks in our index and ask if there
@@ -292,12 +370,17 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
 
                 // Tuples is an array of strings
                 for (let chunkKey of keys) {
-                    if (!this.index.updateDateByChunkKey.hasOwnProperty(chunkKey)) {
+                    if (
+                        !this.index.updateDateByChunkKey.hasOwnProperty(
+                            chunkKey
+                        )
+                    ) {
                         this.index.updateDateByChunkKey[chunkKey] = null;
                         keysNeedingUpdate.push(chunkKey);
-
-                    } else if (this.index.updateDateByChunkKey[chunkKey]
-                        != serverIndex.updateDateByChunkKey[chunkKey]) {
+                    } else if (
+                        this.index.updateDateByChunkKey[chunkKey] !=
+                        serverIndex.updateDateByChunkKey[chunkKey]
+                    ) {
                         keysNeedingUpdate.push(chunkKey);
                     }
                 }
@@ -305,7 +388,6 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
             });
     }
 
-
     /** Queue Chunks To Ask Server
      *
      */
@@ -318,7 +400,8 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
         let indexChunk = new BranchIndexUpdateDateTuple();
 
         for (let key of keysNeedingUpdate) {
-            indexChunk.updateDateByChunkKey[key] = this.index.updateDateByChunkKey[key];
+            indexChunk.updateDateByChunkKey[key] =
+                this.index.updateDateByChunkKey[key] || "";
             count++;
 
             if (count == this.UPDATE_CHUNK_FETCH_SIZE) {
@@ -328,8 +411,7 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
             }
         }
 
-        if (count)
-            this.askServerChunks.push(indexChunk);
+        if (count) this.askServerChunks.push(indexChunk);
 
         this.askServerForNextUpdateChunk();
 
@@ -339,180 +421,127 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
     private askServerForNextUpdateChunk() {
         if (!this.areWeTalkingToTheServer()) return;
 
-        if (this.askServerChunks.length == 0)
-            return;
+        if (this.askServerChunks.length == 0) return;
 
-        let indexChunk: BranchIndexUpdateDateTuple = this.askServerChunks.pop();
-        let filt = extend({}, clientBranchIndexWatchUpdateFromDeviceFilt);
-        filt[cacheAll] = true;
-        let pl = new Payload(filt, [indexChunk]);
-        this.vortexService.sendPayload(pl);
+        this.deviceCacheControllerService //
+            .waitForGarbageCollector()
+            .then(() => {
+                let indexChunk: BranchIndexUpdateDateTuple =
+                    this.askServerChunks.pop();
+                let filt = extend(
+                    {},
+                    clientBranchIndexWatchUpdateFromDeviceFilt
+                );
+                filt[cacheAll] = true;
+                let pl = new Payload(filt, [indexChunk]);
+                this.vortexService.sendPayload(pl);
 
-        this._status.lastCheck = new Date();
-        this._notifyStatus();
+                this._status.lastCheck = new Date();
+                this._notifyStatus();
+            });
     }
 
-
     /** Process BranchIndexes From Server
      *
      * Process the grids the server has sent us.
      */
-    private processBranchIndexsFromServer(payloadEnvelope: PayloadEnvelope) {
-
+    private async processChunksFromServer(
+        payloadEnvelope: PayloadEnvelope
+    ): Promise<void> {
         if (payloadEnvelope.result != null && payloadEnvelope.result != true) {
             console.log(`ERROR: ${payloadEnvelope.result}`);
             return;
         }
 
-        payloadEnvelope
-            .decodePayload()
-            .then((payload: Payload) => this.storeBranchIndexPayload(payload))
-            .then(() => {
-                if (this.askServerChunks.length == 0) {
-                    this.index.initialLoadComplete = true;
-                    this._hasLoaded = true;
-                    this._hasLoadedSubject.next();
+        const tuplesToSave: BranchIndexEncodedChunkTuple[] = <
+            BranchIndexEncodedChunkTuple[]
+        >payloadEnvelope.data;
 
-                } else if (payloadEnvelope.filt[cacheAll] == true) {
-                    this.askServerForNextUpdateChunk();
+        try {
+            await this.storeChunkTuples(tuplesToSave);
+        } catch (e) {
+            console.log(`BranchIndexCache.storeChunkTuples: ${e}`);
+        }
 
-                }
-
-            })
-            .then(() => this._notifyStatus())
-            .catch(e =>
-                `BranchIndexCache.processBranchIndexsFromServer failed: ${e}`
-            );
-
-    }
-
-    private storeBranchIndexPayload(payload: Payload) {
-
-        let tuplesToSave: BranchIndexEncodedChunkTuple[] = <BranchIndexEncodedChunkTuple[]>payload.tuples;
-        if (tuplesToSave.length == 0)
-            return;
-
-        // 2) Store the index
-        this.storeBranchIndexChunkTuples(tuplesToSave)
-            .then(() => {
-                // 3) Store the update date
-
-                for (let diagramIndex of tuplesToSave) {
-                    this.index.updateDateByChunkKey[diagramIndex.chunkKey] = diagramIndex.lastUpdate;
-                }
-
-                return this.storage.saveTuples(
-                    new UpdateDateTupleSelector(), [this.index]
-                );
-
-            })
-            .catch(e => console.log(
-                `BranchIndexCache.storeBranchIndexPayload: ${e}`));
+        if (this.askServerChunks.length == 0) {
+            this.index.initialLoadComplete = true;
+            await this.saveChunkCacheIndex(true);
+            this._hasLoaded = true;
+            this._hasLoadedSubject.next();
+        } else if (payloadEnvelope.filt[cacheAll] == true) {
+            this.askServerForNextUpdateChunk();
+        }
 
+        this._notifyStatus();
     }
 
     /** Store Index Bucket
      * Stores the index bucket in the local db.
      */
-    private storeBranchIndexChunkTuples(encodedBranchIndexChunkTuples: BranchIndexEncodedChunkTuple[]): Promise<void> {
-        let retPromise: any;
-        retPromise = this.storage.transaction(true)
-            .then((tx) => {
+    private async storeChunkTuples(
+        tuplesToSave: BranchIndexEncodedChunkTuple[]
+    ): Promise<void> {
+        // noinspection BadExpressionStatementJS
+        const Selector = BranchIndexChunkTupleSelector;
 
-                let promises = [];
+        if (tuplesToSave.length == 0) return;
 
-                for (let encodedBranchIndexChunkTuple of encodedBranchIndexChunkTuples) {
-                    promises.push(
-                        tx.saveTuplesEncoded(
-                            new BranchIndexChunkTupleSelector(encodedBranchIndexChunkTuple.chunkKey),
-                            encodedBranchIndexChunkTuple.encodedData
-                        )
-                    );
-                }
-
-                return Promise.all(promises)
-                    .then(() => tx.close());
+        const batchStore: TupleStorageBatchSaveArguments[] = [];
+        for (const tuple of tuplesToSave) {
+            batchStore.push({
+                tupleSelector: new Selector(tuple.chunkKey),
+                vortexMsg: tuple.encodedData,
             });
-        return retPromise;
+        }
+
+        await this.storage.batchSaveTuplesEncoded(batchStore);
+
+        for (const tuple of tuplesToSave) {
+            this.index.updateDateByChunkKey[tuple.chunkKey] = tuple.lastUpdate;
+        }
+        await this.saveChunkCacheIndex();
     }
 
-
-    /** Get BranchIndexs
+    /** Store Chunk Cache Index
      *
-     * Get the objects with matching keywords from the index..
-     *
-     * @param: modelSetKey: The model set that the branches live in
-     * @param: coordSetId: Get the branch that lives in this coordSet, or null to return
-     *          branches living in all coord sets.
-     * @param: keys: The keys to load the branches for.
+     * Updates our running tab of the update dates of the cached chunks
      *
      */
-    getBranches(modelSetKey: string,
-                coordSetId: number | null,
-                keys: string[]): Promise<BranchIndexResultI> {
-        if (modelSetKey == null || modelSetKey.length == 0) {
-            Promise.reject("We've been passed a null/empty modelSetKey");
+    private async saveChunkCacheIndex(force = false): Promise<void> {
+        if (
+            this.chunksSavedSinceLastIndexSave <= this.SAVE_POINT_ITERATIONS &&
+            !force
+        ) {
+            return;
         }
 
-        if (keys == null || keys.length == 0) {
-            Promise.reject("We've been passed a null/empty keys");
-        }
+        this.chunksSavedSinceLastIndexSave = 0;
 
-        // If there is no offline support, or we're online
-        if (!this.offlineConfig.cacheChunksForOffline
-            || this.vortexStatusService.snapshot.isOnline) {
-            let ts = new TupleSelector(BranchTuple.tupleName, {
-                "modelSetKey": modelSetKey,
-                "coordSetId": coordSetId,
-                "keys": keys
-            });
-
-            let isOnlinePromise: any = this.vortexStatusService.snapshot.isOnline ?
-                Promise.resolve() :
-                this.vortexStatusService.isOnline
-                    .filter(online => online)
-                    .first()
-                    .toPromise();
-
-            return isOnlinePromise
-                .then(() => this.tupleService.offlineObserver.pollForTuples(ts, false))
-                .then((docs: BranchTuple[]) => this._populateAndIndexObjectTypes(docs));
-        }
-
-
-        // If we do have offline support
-        if (this.isReady())
-            return this.getBranchesWhenReady(modelSetKey, coordSetId, keys)
-                .then(docs => this._populateAndIndexObjectTypes(docs));
-
-        return this.isReadyObservable()
-            .first()
-            .toPromise()
-            .then(() => this.getBranchesWhenReady(modelSetKey, coordSetId, keys))
-            .then(docs => this._populateAndIndexObjectTypes(docs));
+        await this.storage.saveTuples(new UpdateDateTupleSelector(), [
+            this.index,
+        ]);
     }
 
-
     /** Get BranchIndexs When Ready
      *
      * Get the objects with matching keywords from the index..
      *
      */
-    private getBranchesWhenReady(
-        modelSetKey: string, coordSetId: number, keys: string[]): Promise<BranchTuple[]> {
-
-        let keysByChunkKey: { [key: string]: string[]; } = {};
+    private getChunksWhenReady(
+        modelSetKey: string,
+        coordSetId: number,
+        keys: string[]
+    ): Promise<BranchTuple[]> {
+        let keysByChunkKey: { [key: string]: string[] } = {};
         let chunkKeys: string[] = [];
 
         for (let key of keys) {
             let chunkKey: string = keyChunk(modelSetKey, key);
-            if (keysByChunkKey[chunkKey] == null)
-                keysByChunkKey[chunkKey] = [];
+            if (keysByChunkKey[chunkKey] == null) keysByChunkKey[chunkKey] = [];
             keysByChunkKey[chunkKey].push(key);
             chunkKeys.push(chunkKey);
         }
 
-
         let promises = [];
         for (let chunkKey of chunkKeys) {
             let keysForThisChunk = keysByChunkKey[chunkKey];
@@ -521,26 +550,27 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
             );
         }
 
-        return Promise.all(promises)
-            .then((promiseResults: BranchTuple[][]) => {
-                let objects: BranchTuple[] = [];
-                for (let results of  promiseResults) {
-                    for (let result of results) {
-                        objects.push(result);
-                    }
+        return Promise.all(promises).then((promiseResults: BranchTuple[][]) => {
+            let objects: BranchTuple[] = [];
+            for (let results of promiseResults) {
+                for (let result of results) {
+                    objects.push(result);
                 }
-                return objects;
-            });
+            }
+            return objects;
+        });
     }
 
-
     /** Get BranchIndexs for Object ID
      *
      * Get the objects with matching keywords from the index..
      *
      */
-    private getBranchesForKeys(coordSetId: number, keys: string[], chunkKey: string): Promise<BranchTuple[]> {
-
+    private getBranchesForKeys(
+        coordSetId: number,
+        keys: string[],
+        chunkKey: string
+    ): Promise<BranchTuple[]> {
         if (!this.index.updateDateByChunkKey.hasOwnProperty(chunkKey)) {
             console.log(`ObjectIDs: ${keys} doesn't appear in the index`);
             return Promise.resolve([]);
@@ -554,19 +584,17 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
                     return [];
                 }
 
-
                 return Payload.fromEncodedPayload(vortexMsg)
                     .then((payload: Payload) => JSON.parse(<any>payload.tuples))
-                    .then((chunkData: { [key: number]: string; }) => {
-
+                    .then((chunkData: { [key: number]: string }) => {
                         let foundBranchIndexs: BranchTuple[] = [];
 
                         for (let key of keys) {
                             // Find the keyword, we're just iterating
                             if (!chunkData.hasOwnProperty(key)) {
                                 console.log(
-                                    `WARNING: BranchIndex ${key} is missing from index,`
-                                    + ` chunkKey ${chunkKey}`
+                                    `WARNING: BranchIndex ${key} is missing from index,` +
+                                        ` chunkKey ${chunkKey}`
                                 );
                                 continue;
                             }
@@ -574,31 +602,29 @@ export class BranchIndexLoaderService extends BranchIndexLoaderServiceA {
                             let packedJsons = chunkData[key];
                             for (let packedJson of packedJsons) {
                                 let branch = BranchTuple.unpackJson(packedJson);
-                                if (branch.coordSetId == coordSetId || coordSetId == null)
+                                if (
+                                    branch.coordSetId == coordSetId ||
+                                    coordSetId == null
+                                )
                                     foundBranchIndexs.push(branch);
                             }
-
                         }
 
                         return foundBranchIndexs;
-
                     });
             });
 
         return retPromise;
-
     }
 
-    private _populateAndIndexObjectTypes(results: BranchTuple[]): BranchIndexResultI {
-
+    private _populateAndIndexObjectTypes(
+        results: BranchTuple[]
+    ): BranchIndexResultI {
         let objects: { [key: string]: BranchTuple[] } = {};
         for (let result of results) {
-            if (objects[result.key] == null)
-                objects[result.key] = [];
+            if (objects[result.key] == null) objects[result.key] = [];
             objects[result.key].push(result);
         }
         return objects;
     }
-
-
-}
\ No newline at end of file
+}
