@@ -1,11 +1,16 @@
-import {addTupleType, deepCopy, Tuple} from "@synerty/vortexjs";
-import {diagramTuplePrefix} from "../PluginNames";
-import {SerialiseUtil} from "@synerty/vortexjs";
+import {
+    addTupleType,
+    deepCopy,
+    SerialiseUtil,
+    Tuple,
+} from "@synerty/vortexjs";
+import { diagramTuplePrefix } from "../PluginNames";
 import * as moment from "moment";
-import {BranchLiveEditTuple} from "./BranchLiveEditTuple";
-import {PrivateDiagramLookupService} from "../services/PrivateDiagramLookupService";
+import { BranchLiveEditTuple } from "./BranchLiveEditTuple";
+import { PrivateDiagramLookupService } from "../services/PrivateDiagramLookupService";
 
 let serUril = new SerialiseUtil();
+declare var require: any;
 
 interface UndoDataI {
     disps: any[];
@@ -20,7 +25,7 @@ export interface BranchLastEditPositionI {
     x: number;
     y: number;
     zoom: number;
-    coordSetKey: string
+    coordSetKey: string;
 }
 
 /** Diagram Branch Tuple
@@ -32,12 +37,6 @@ export interface BranchLastEditPositionI {
 @addTupleType
 export class BranchTuple extends Tuple {
     public static readonly tupleName = diagramTuplePrefix + "BranchTuple";
-
-    protected _rawJonableFields = ['packedJson__'];
-
-    // The list of deltas for this branch
-    packedJson__: any[] = [];
-
     private static readonly __ID_NUM = 0;
     private static readonly __COORD_SET_ID_NUM = 1;
     private static readonly __KEY_NUM = 2;
@@ -50,7 +49,9 @@ export class BranchTuple extends Tuple {
     private static readonly __NEEDS_SAVE_NUM = 9; // Not stored in DB
     private static readonly __LAST_EDIT_POSITION = 10;
     private static readonly __LAST_INDEX_NUM = 10;
-
+    // The list of deltas for this branch
+    packedJson__: any[] = [];
+    protected _rawJonableFields = ["packedJson__"];
 
     // This structure stores IDs that need to be updated, from disps that have been
     // cloned from disps their replacing (their ID is re-assigned)
@@ -58,20 +59,90 @@ export class BranchTuple extends Tuple {
     private _replacementIds = {};
     private _dispsById = {};
     private _lastStage = 1;
-    private _contextUpdateCallback: ((modelUpdateRequired: boolean) => void) | null;
+    private _contextUpdateCallback:
+        | ((modelUpdateRequired: boolean) => void)
+        | null;
 
     // Undo / Redo
     private undoQueue: string[] = [];
     private redoQueue: string[] = [];
     private readonly MAX_UNDO = 20;
 
-
     constructor() {
         super(BranchTuple.tupleName);
-        for (let i = this.packedJson__.length; i < BranchTuple.__LAST_INDEX_NUM + 1; i++)
+        for (
+            let i = this.packedJson__.length;
+            i < BranchTuple.__LAST_INDEX_NUM + 1;
+            i++
+        )
             this.packedJson__.push(null);
     }
 
+    get needsSave(): boolean {
+        return this.packedJson__[BranchTuple.__NEEDS_SAVE_NUM];
+    }
+
+    get id(): number {
+        return this.packedJson__[BranchTuple.__ID_NUM];
+    }
+
+    get coordSetId(): number {
+        return this.packedJson__[BranchTuple.__COORD_SET_ID_NUM];
+    }
+
+    get key(): string {
+        return this.packedJson__[BranchTuple.__KEY_NUM];
+    }
+
+    get updatedByUser(): string {
+        return this.packedJson__[BranchTuple.__UPDATED_BY_USER_NUM];
+    }
+
+    set updatedByUser(val: string) {
+        this.packedJson__[BranchTuple.__UPDATED_BY_USER_NUM] = val;
+    }
+
+    get lastEditPosition(): BranchLastEditPositionI | null {
+        const jsonStr = this.packedJson__[BranchTuple.__LAST_EDIT_POSITION];
+        if (jsonStr == null || jsonStr.length == 0) return null;
+        return JSON.parse(jsonStr);
+    }
+
+    set lastEditPosition(position: BranchLastEditPositionI) {
+        this.packedJson__[BranchTuple.__LAST_EDIT_POSITION] =
+            JSON.stringify(position);
+    }
+
+    get disps(): any[] {
+        return this._array(BranchTuple.__DISPS_NUM).slice();
+    }
+
+    get anchorDispKeys(): string[] {
+        return this._array(BranchTuple.__ANCHOR_DISP_KEYS_NUM).slice();
+    }
+
+    get visible(): boolean {
+        return this.packedJson__[BranchTuple.__VISIBLE_NUM];
+    }
+
+    set visible(value: boolean) {
+        this.packedJson__[BranchTuple.__VISIBLE_NUM] = value;
+    }
+
+    get updatedDate(): Date | null {
+        let packedDate = this.packedJson__[BranchTuple.__UPDATED_DATE];
+        if (packedDate == null) return packedDate;
+
+        return serUril.fromStr(packedDate, SerialiseUtil.T_DATETIME);
+    }
+
+    get createdDate(): Date {
+        return serUril.fromStr(
+            this.packedJson__[BranchTuple.__CREATED_DATE],
+            SerialiseUtil.T_DATETIME
+        );
+    }
+
     static createBranch(coordSetId: number, branchKey: string): any {
         let branch = new BranchTuple();
         branch.packedJson__[BranchTuple.__ID_NUM] = this._makeUniqueId();
@@ -98,98 +169,26 @@ export class BranchTuple extends Tuple {
         return newSelf;
     }
 
-    private assignIdsToDisps(): void {
-        let DispBase = require("peek_plugin_diagram/canvas-shapes/DispBase")["DispBase"];
-        let array = this._array(BranchTuple.__DISPS_NUM);
-        for (let i = 0; i < array.length; ++i) {
-            let disp = array[i];
-            BranchTuple._setNewDispId(disp, i);
-            this._dispsById[DispBase.id(disp)] = disp;
-            if (this._lastStage < DispBase.branchStage(disp))
-                this._lastStage = DispBase.branchStage(disp);
-        }
-    }
-
     private static _makeUniqueId(index = -1): any {
-        return <any>`NEW_${(new Date()).getTime()}_${index}`;
+        return <any>`NEW_${new Date().getTime()}_${index}`;
     }
 
     private static _setNewDispId(disp, index): void {
-        let DispBase = require("peek_plugin_diagram/canvas-shapes/DispBase")["DispBase"];
+        let DispBase =
+            require("@_peek/peek_plugin_diagram/canvas-shapes/DispBase")[
+                "DispBase"
+            ];
         let newId = this._makeUniqueId(index);
 
-        if (DispBase.id(disp) == null)
-            DispBase.setId(disp, newId);
+        if (DispBase.id(disp) == null) DispBase.setId(disp, newId);
 
-        if (DispBase.hashId(disp) == null)
-            DispBase.setHashId(disp, newId);
-    }
-
-    private _array(num: number): any[] {
-        if (this.packedJson__[num] == null)
-            this.packedJson__[num] = [];
-        return this.packedJson__[num];
-    }
-
-    get needsSave(): boolean {
-        return this.packedJson__[BranchTuple.__NEEDS_SAVE_NUM];
-    }
-
-    get isUndoPossible(): boolean {
-        return this.undoQueue.length > 1;
-    }
-
-    get isRedoPossible(): boolean {
-        return this.redoQueue.length != 0
-    }
-
-    private resetUndo(): void {
-        this.undoQueue = [this.serialiseDisps()];
-    }
-
-    private resetRedo(): void {
-        this.redoQueue = [];
+        if (DispBase.hashId(disp) == null) DispBase.setHashId(disp, newId);
     }
 
     branchHasBeenSaved(): void {
         this.packedJson__[BranchTuple.__NEEDS_SAVE_NUM] = false;
     }
 
-    private setNeedsSave(): void {
-        this.packedJson__[BranchTuple.__NEEDS_SAVE_NUM] = true;
-    }
-
-    get id(): number {
-        return this.packedJson__[BranchTuple.__ID_NUM];
-    }
-
-    get coordSetId(): number {
-        return this.packedJson__[BranchTuple.__COORD_SET_ID_NUM];
-    }
-
-    get key(): string {
-        return this.packedJson__[BranchTuple.__KEY_NUM];
-    }
-
-    get updatedByUser(): string {
-        return this.packedJson__[BranchTuple.__UPDATED_BY_USER_NUM];
-    }
-
-    set updatedByUser(val: string) {
-        this.packedJson__[BranchTuple.__UPDATED_BY_USER_NUM] = val;
-    }
-
-    set lastEditPosition(position: BranchLastEditPositionI) {
-        this.packedJson__[BranchTuple.__LAST_EDIT_POSITION] = JSON.stringify(position);
-    }
-
-    get lastEditPosition(): BranchLastEditPositionI | null {
-        const jsonStr = this.packedJson__[BranchTuple.__LAST_EDIT_POSITION];
-        if (jsonStr == null || jsonStr.length == 0)
-            return null;
-        return JSON.parse(jsonStr);
-    }
-
     addStage(): number {
         return this._lastStage++;
     }
@@ -207,12 +206,12 @@ export class BranchTuple extends Tuple {
 
         for (let disp of disps) {
             let result = this.addOrUpdateSingleDisp(disp);
-            modelUpdateRequired = modelUpdateRequired || result.modelUpdateRequired;
+            modelUpdateRequired =
+                modelUpdateRequired || result.modelUpdateRequired;
             returnedDisps.push(result.disp);
         }
 
-        for (let disp of returnedDisps)
-            this.updateReplacedIds(disp);
+        for (let disp of returnedDisps) this.updateReplacedIds(disp);
 
         this.sortDisps();
         this.touchUpdateDate(modelUpdateRequired && !preventModelUpdate);
@@ -238,21 +237,295 @@ export class BranchTuple extends Tuple {
     }
 
     isDispInBranch(disp: any): boolean {
-        let DispBase = require("peek_plugin_diagram/canvas-shapes/DispBase")["DispBase"];
-        return this._dispsById[DispBase.id(disp)] != null
-            || this._replacementIds[DispBase.id(disp)] != null;
+        // @ts-ignore
+        let DispBase =
+            require("@_peek/peek_plugin_diagram/canvas-shapes/DispBase")[
+                "DispBase"
+            ];
+        return (
+            this._dispsById[DispBase.id(disp)] != null ||
+            this._replacementIds[DispBase.id(disp)] != null
+        );
+    }
+
+    /** Add New Disps
+     *
+     * This method adds newly created disps to tbe branch in bulk.
+     *
+     * @param disps
+     */
+    addNewDisps(disps: any[]): void {
+        // @ts-ignore
+        let DispBase =
+            require("@_peek/peek_plugin_diagram/canvas-shapes/DispBase")[
+                "DispBase"
+            ];
+        let array = this._array(BranchTuple.__DISPS_NUM);
+
+        for (let disp of disps) {
+            BranchTuple._setNewDispId(disp, array.length);
+            DispBase.setBranchStage(disp, this._lastStage);
+            this._dispsById[DispBase.id(disp)] = disp;
+            array.push(disp);
+        }
+        this.sortDisps();
+        this.touchUpdateDate(true);
+    }
+
+    removeDisps(disps: any[]): void {
+        // @ts-ignore
+        let DispBase =
+            require("@_peek/peek_plugin_diagram/canvas-shapes/DispBase")[
+                "DispBase"
+            ];
+        // @ts-ignore
+        let DispNull =
+            require("@_peek/peek_plugin_diagram/canvas-shapes/DispNull")[
+                "DispNull"
+            ];
+
+        let dispIdsToRemove = {};
+        for (let disp of disps) {
+            dispIdsToRemove[DispBase.id(disp)] = disp;
+        }
+
+        let array = this._array(BranchTuple.__DISPS_NUM);
+        let branchDispsToBeConvertedToNullDisps = [];
+
+        // Filter out disps in this branch that we're deleting
+        // If the disp we're deleting replacing anoter disp (not in this branch)
+        //      make a note of that.
+        this.packedJson__[BranchTuple.__DISPS_NUM] = array.filter((disp) => {
+            let id = DispBase.id(disp);
+            if (dispIdsToRemove[id] != null) {
+                if (DispBase.replacesHashId(disp) != null)
+                    branchDispsToBeConvertedToNullDisps.push(disp);
+                delete dispIdsToRemove[id];
+                return false;
+            }
+            return true;
+        });
+
+        // Update the dispId dict to remove the disps we just filtered out
+        this.assignIdsToDisps();
+
+        // For all the Disps that are not part of this branch, we need to add a DispNull
+        // to make it's deletion
+
+        let nullDispsToCreate = [];
+
+        function createNullDisp(dispToDelete, replacesHashId) {
+            if (dispToDelete.bounds == null)
+                throw new Error("Can not delete a disp with no bounds");
+
+            let nullDisp = {
+                // Type
+                _tt: DispBase.TYPE_DN,
+
+                // Level
+                le: dispToDelete.le,
+                lel: dispToDelete.lel,
+
+                // Layer
+                la: dispToDelete.la,
+                lal: dispToDelete.lal,
+            };
+
+            DispNull.setGeomFromBounds(nullDisp, dispToDelete.bounds);
+            DispBase.setReplacesHashId(nullDisp, replacesHashId);
+            nullDispsToCreate.push(nullDisp);
+        }
+
+        // For all the Disps that are not part of this branch, we need to add a DispNull
+        // to make it's deletion
+        // Create NULL disps for disps being deleted that are not part of this branch
+        for (let dispId of Object.keys(dispIdsToRemove)) {
+            let disp = dispIdsToRemove[dispId];
+            createNullDisp(disp, DispBase.hashId(disp));
+        }
+
+        // For all disps that are part of this branch, but replace other disps,
+        // Create NULL disps for disps in this branch that replace other disps
+        for (let disp of branchDispsToBeConvertedToNullDisps) {
+            createNullDisp(disp, DispBase.replacesHashId(disp));
+        }
+
+        if (nullDispsToCreate.length != 0) this.addNewDisps(nullDispsToCreate);
+        else this.touchUpdateDate(false);
+    }
+
+    addAnchorDispKey(key: string): void {
+        let anchors = this._array(BranchTuple.__ANCHOR_DISP_KEYS_NUM);
+        if (anchors.filter((k) => k == key).length != 0) return;
+
+        this.touchUpdateDate(false);
+        anchors.push(key);
+    }
+
+    touchUpdateDate(modelUpdateRequired: boolean = false): void {
+        this.setNeedsSave();
+        this.setUpdatedDate(new Date());
+        if (this._contextUpdateCallback != null)
+            this._contextUpdateCallback(modelUpdateRequired);
+    }
+
+    touchUndo(): void {
+        const current = this.serialiseDisps();
+
+        // If there is no change, queue nothing
+        const len = this.undoQueue.length;
+        if (len != 0 && this.undoQueue[len - 1] == current) return;
+
+        this.undoQueue.push(current);
+        this.resetRedo();
+
+        while (this.undoQueue.length > this.MAX_UNDO) this.undoQueue.shift();
+    }
+
+    get canUndo(): boolean {
+        return this.undoQueue.length > 1;
+    }
+
+    doUndo(lookupService: PrivateDiagramLookupService): void {
+        if (this.undoQueue.length <= 1) return;
+
+        const len = this.undoQueue.length;
+        this.redoQueue.push(this.undoQueue.pop());
+        this.restoreSerialisedDisps(this.undoQueue[len - 2]);
+
+        this.linkDisps(lookupService);
+        this.touchUpdateDate(true);
+    }
+
+    get canRedo(): boolean {
+        return this.redoQueue.length !== 0;
+    }
+
+    doRedo(lookupService: PrivateDiagramLookupService): void {
+        if (this.redoQueue.length == 0) return;
+
+        const redo = this.redoQueue.pop();
+        this.undoQueue.push(redo);
+        this.restoreSerialisedDisps(redo);
+
+        this.linkDisps(lookupService);
+        this.touchUpdateDate(true);
+    }
+
+    toJsonField(
+        value: any,
+        jsonDict: {} | null = null,
+        name: string | null = null
+    ): any {
+        // @ts-ignore
+        const DispBase =
+            require("@_peek/peek_plugin_diagram/canvas-shapes/DispBase")[
+                "DispBase"
+            ];
+        if (name != "packedJson__")
+            return Tuple.prototype.toJsonField(value, jsonDict, name);
+
+        const convertedValue = deepCopy(
+            value,
+            DispBase.DEEP_COPY_FIELDS_TO_IGNORE
+        );
+
+        let disps = convertedValue[BranchTuple.__DISPS_NUM];
+
+        this.cleanClonedDisps(disps);
+
+        /* Now assign the value and it's value type if applicable */
+        if (name != null && jsonDict != null) jsonDict[name] = convertedValue;
+
+        return convertedValue;
+    }
+
+    linkDisps(lookupService: PrivateDiagramLookupService) {
+        for (let disp of this.disps) {
+            lookupService._linkDispLookups(disp);
+        }
+    }
+
+    setContextUpdateCallback(
+        contextUpdateCallback: ((modelUpdateRequired: boolean) => void) | null
+    ) {
+        this._contextUpdateCallback = contextUpdateCallback;
+    }
+
+    applyLiveUpdate(liveEditTuple: BranchLiveEditTuple): boolean {
+        let liveUpdateTuple = liveEditTuple.branchTuple;
+
+        if (
+            this.updatedDate == null ||
+            moment(this.updatedDate).isBefore(liveUpdateTuple.updatedDate) ||
+            liveEditTuple.updateFromSave
+        ) {
+            this.packedJson__ = liveUpdateTuple.packedJson__;
+            this.assignIdsToDisps();
+            this.resetUndo();
+            this.resetRedo();
+            return true;
+        }
+        return false;
+    }
+
+    private assignIdsToDisps(): void {
+        // @ts-ignore
+        let DispBase =
+            require("@_peek/peek_plugin_diagram/canvas-shapes/DispBase")[
+                "DispBase"
+            ];
+        let array = this._array(BranchTuple.__DISPS_NUM);
+        for (let i = 0; i < array.length; ++i) {
+            let disp = array[i];
+            BranchTuple._setNewDispId(disp, i);
+            this._dispsById[DispBase.id(disp)] = disp;
+            if (this._lastStage < DispBase.branchStage(disp))
+                this._lastStage = DispBase.branchStage(disp);
+        }
+    }
+
+    private _array(num: number): any[] {
+        if (this.packedJson__[num] == null) this.packedJson__[num] = [];
+        return this.packedJson__[num];
+    }
+
+    private resetUndo(): void {
+        this.undoQueue = [this.serialiseDisps()];
+    }
+
+    private resetRedo(): void {
+        this.redoQueue = [];
+    }
+
+    private setNeedsSave(): void {
+        this.packedJson__[BranchTuple.__NEEDS_SAVE_NUM] = true;
     }
 
     private updateReplacedIds(disp) {
-        let DispBase = require("peek_plugin_diagram/canvas-shapes/DispBase")["DispBase"];
+        // @ts-ignore
+        let DispBase =
+            require("@_peek/peek_plugin_diagram/canvas-shapes/DispBase")[
+                "DispBase"
+            ];
         let newGroupId = this._replacementIds[DispBase.groupId(disp)];
-        if (newGroupId != null)
-            DispBase.setGroupId(disp, newGroupId);
+        if (newGroupId != null) DispBase.setGroupId(disp, newGroupId);
     }
 
-    private addOrUpdateSingleDisp(disp: any): { disp: any, modelUpdateRequired: boolean } {
-        let DispBase = require("peek_plugin_diagram/canvas-shapes/DispBase")["DispBase"];
-        let DispGroupPointer = require("peek_plugin_diagram/canvas-shapes/DispGroupPointer")["DispGroupPointer"];
+    private addOrUpdateSingleDisp(disp: any): {
+        disp: any;
+        modelUpdateRequired: boolean;
+    } {
+        // @ts-ignore
+        let DispBase =
+            require("@_peek/peek_plugin_diagram/canvas-shapes/DispBase")[
+                "DispBase"
+            ];
+        // @ts-ignore
+        let DispGroupPointer =
+            require("@_peek/peek_plugin_diagram/canvas-shapes/DispGroupPointer")[
+                "DispGroupPointer"
+            ];
         let array = this._array(BranchTuple.__DISPS_NUM);
 
         // If we've already replaced this Disp, then just return the replacement disp
@@ -260,7 +533,7 @@ export class BranchTuple extends Tuple {
         // times. (They have a selected and related array)
         if (this._replacementIds[DispBase.id(disp)] != null) {
             let newId = this._replacementIds[DispBase.id(disp)];
-            return {disp: this._dispsById[newId], modelUpdateRequired: false};
+            return { disp: this._dispsById[newId], modelUpdateRequired: false };
         }
 
         // Find out if the disp is in this branch
@@ -290,250 +563,53 @@ export class BranchTuple extends Tuple {
             DispBase.setBranchStage(disp, this._lastStage);
             this._dispsById[DispBase.id(disp)] = disp;
             array.push(disp);
-            return {disp: disp, modelUpdateRequired: true};
+            return { disp: disp, modelUpdateRequired: true };
         }
 
         if (DispBase.branchStage(dispInBranch) == DispBase.branchStage(disp)) {
-            return {disp: disp, modelUpdateRequired: false};
+            return { disp: disp, modelUpdateRequired: false };
         }
 
         // Else, it's a new stage, clone the disp.
 
         this._dispsById[DispBase.id(disp)] = disp;
         array.push(disp);
-        return {disp: disp, modelUpdateRequired: true};
-
+        return { disp: disp, modelUpdateRequired: true };
     }
 
     private sortDisps(): void {
-        const sortDisps = require("peek_plugin_diagram/canvas/PeekCanvasModelUtil.web")
-            ["sortDisps"];
+        // @ts-ignore
+        const sortDisps =
+            require("@_peek/peek_plugin_diagram/canvas/PeekCanvasModelUtil.web")[
+                "sortDisps"
+            ];
 
         let array = this._array(BranchTuple.__DISPS_NUM);
         this.packedJson__[BranchTuple.__DISPS_NUM] = sortDisps(array);
     }
 
-    /** Add New Disps
-     *
-     * This method adds newly created disps to tbe branch in bulk.
-     *
-     * @param disps
-     */
-    addNewDisps(disps: any[]): void {
-        let DispBase = require("peek_plugin_diagram/canvas-shapes/DispBase")["DispBase"];
-        let array = this._array(BranchTuple.__DISPS_NUM);
-
-        for (let disp of disps) {
-            BranchTuple._setNewDispId(disp, array.length);
-            DispBase.setBranchStage(disp, this._lastStage);
-            this._dispsById[DispBase.id(disp)] = disp;
-            array.push(disp);
-        }
-        this.sortDisps();
-        this.touchUpdateDate(true);
-
-    }
-
-    removeDisps(disps: any[]): void {
-        let DispBase = require("peek_plugin_diagram/canvas-shapes/DispBase")["DispBase"];
-        let DispNull = require("peek_plugin_diagram/canvas-shapes/DispNull")["DispNull"];
-
-        let dispIdsToRemove = {};
-        for (let disp of disps) {
-            dispIdsToRemove[DispBase.id(disp)] = disp;
-        }
-
-        let array = this._array(BranchTuple.__DISPS_NUM);
-        let branchDispsToBeConvertedToNullDisps = [];
-
-        // Filter out disps in this branch that we're deleting
-        // If the disp we're deleting replacing anoter disp (not in this branch)
-        //      make a note of that.
-        this.packedJson__[BranchTuple.__DISPS_NUM] = array
-            .filter(disp => {
-                let id = DispBase.id(disp);
-                if (dispIdsToRemove[id] != null) {
-                    if (DispBase.replacesHashId(disp) != null)
-                        branchDispsToBeConvertedToNullDisps.push(disp);
-                    delete dispIdsToRemove[id];
-                    return false;
-                }
-                return true;
-
-            });
-
-        // Update the dispId dict to remove the disps we just filtered out
-        this.assignIdsToDisps();
-
-        // For all the Disps that are not part of this branch, we need to add a DispNull
-        // to make it's deletion
-
-        let nullDispsToCreate = [];
-
-        function createNullDisp(dispToDelete, replacesHashId) {
-            if (dispToDelete.bounds == null)
-                throw new Error("Can not delete a disp with no bounds");
-
-            let nullDisp = {
-                // Type
-                '_tt': DispBase.TYPE_DN,
-
-                // Level
-                'le': dispToDelete.le,
-                'lel': dispToDelete.lel,
-
-                // Layer
-                'la': dispToDelete.la,
-                'lal': dispToDelete.lal,
-            };
-
-            DispNull.setGeomFromBounds(nullDisp, dispToDelete.bounds);
-            DispBase.setReplacesHashId(nullDisp, replacesHashId);
-            nullDispsToCreate.push(nullDisp);
-        }
-
-        // For all the Disps that are not part of this branch, we need to add a DispNull
-        // to make it's deletion
-        // Create NULL disps for disps being deleted that are not part of this branch
-        for (let dispId of Object.keys(dispIdsToRemove)) {
-            let disp = dispIdsToRemove[dispId];
-            createNullDisp(disp, DispBase.hashId(disp));
-        }
-
-        // For all disps that are part of this branch, but replace other disps,
-        // Create NULL disps for disps in this branch that replace other disps
-        for (let disp of branchDispsToBeConvertedToNullDisps) {
-            createNullDisp(disp, DispBase.replacesHashId(disp));
-        }
-
-        if (nullDispsToCreate.length != 0)
-            this.addNewDisps(nullDispsToCreate);
-        else
-            this.touchUpdateDate(false);
-    }
-
-
-    get disps(): any[] {
-        return this._array(BranchTuple.__DISPS_NUM).slice();
-    }
-
-    addAnchorDispKey(key: string): void {
-        let anchors = this._array(BranchTuple.__ANCHOR_DISP_KEYS_NUM);
-        if (anchors.filter(k => k == key).length != 0)
-            return;
-
-        this.touchUpdateDate(false);
-        anchors.push(key);
-    }
-
-    get anchorDispKeys(): string[] {
-        return this._array(BranchTuple.__ANCHOR_DISP_KEYS_NUM).slice();
-    }
-
-
-    set visible(value: boolean) {
-        this.packedJson__[BranchTuple.__VISIBLE_NUM] = value;
-    }
-
-    get visible(): boolean {
-        return this.packedJson__[BranchTuple.__VISIBLE_NUM];
-    }
-
-    get updatedDate(): Date | null {
-        let packedDate = this.packedJson__[BranchTuple.__UPDATED_DATE];
-        if (packedDate == null)
-            return packedDate;
-
-        return serUril.fromStr(packedDate, SerialiseUtil.T_DATETIME);
-    }
-
     private setUpdatedDate(value: Date | null): void {
-        if (value == null)
-            this.packedJson__[BranchTuple.__UPDATED_DATE] = null;
+        if (value == null) this.packedJson__[BranchTuple.__UPDATED_DATE] = null;
         else
-            this.packedJson__[BranchTuple.__UPDATED_DATE] = serUril.toStr(value);
-    }
-
-    get createdDate(): Date {
-        return serUril.fromStr(this.packedJson__[BranchTuple.__CREATED_DATE],
-            SerialiseUtil.T_DATETIME);
+            this.packedJson__[BranchTuple.__UPDATED_DATE] =
+                serUril.toStr(value);
     }
 
     private setCreatedDate(value: Date): void {
         this.packedJson__[BranchTuple.__CREATED_DATE] = serUril.toStr(value);
     }
 
-    touchUpdateDate(modelUpdateRequired: boolean = false): void {
-        this.setNeedsSave();
-        this.setUpdatedDate(new Date());
-        if (this._contextUpdateCallback != null)
-            this._contextUpdateCallback(modelUpdateRequired);
-    }
-
-    touchUndo(): void {
-        const current = this.serialiseDisps();
-
-        // If there is no change, queue nothing
-        const len = this.undoQueue.length;
-        if (len != 0 && this.undoQueue[len - 1] == current)
-            return;
-
-        this.undoQueue.push(current);
-        this.resetRedo();
-
-        while (this.undoQueue.length > this.MAX_UNDO)
-            this.undoQueue.shift();
-    }
-
-    doUndo(lookupService: PrivateDiagramLookupService): void {
-        if (this.undoQueue.length <= 1)
-            return;
-
-        const len = this.undoQueue.length;
-        this.redoQueue.push(this.undoQueue.pop());
-        this.restoreSerialisedDisps(this.undoQueue[len - 2]);
-
-        this.linkDisps(lookupService);
-        this.touchUpdateDate(true);
-    }
-
-    doRedo(lookupService: PrivateDiagramLookupService): void {
-        if (this.redoQueue.length == 0)
-            return;
-
-        const redo = this.redoQueue.pop();
-        this.undoQueue.push(redo);
-        this.restoreSerialisedDisps(redo);
-
-        this.linkDisps(lookupService);
-        this.touchUpdateDate(true);
-    }
-
-    toJsonField(value: any,
-                jsonDict: {} | null = null,
-                name: string | null = null): any {
-        const DispBase = require("peek_plugin_diagram/canvas-shapes/DispBase")["DispBase"];
-        if (name != "packedJson__")
-            return Tuple.prototype.toJsonField(value, jsonDict, name);
-
-        const convertedValue = deepCopy(value, DispBase.DEEP_COPY_FIELDS_TO_IGNORE);
-
-        let disps = convertedValue[BranchTuple.__DISPS_NUM];
-
-        this.cleanClonedDisps(disps);
-
-        /* Now assign the value and it's value type if applicable */
-        if (name != null && jsonDict != null)
-            jsonDict[name] = convertedValue;
-
-        return convertedValue;
-    }
-
     private serialiseDisps(): string {
-        const DispBase = require("peek_plugin_diagram/canvas-shapes/DispBase")["DispBase"];
+        // @ts-ignore
+        const DispBase =
+            require("@_peek/peek_plugin_diagram/canvas-shapes/DispBase")[
+                "DispBase"
+            ];
 
-        const disps = deepCopy(this._array(BranchTuple.__DISPS_NUM),
-            DispBase.DEEP_COPY_FIELDS_TO_IGNORE);
+        const disps = deepCopy(
+            this._array(BranchTuple.__DISPS_NUM),
+            DispBase.DEEP_COPY_FIELDS_TO_IGNORE
+        );
         this.cleanClonedDisps(disps);
 
         let data: UndoDataI = {
@@ -542,7 +618,7 @@ export class BranchTuple extends Tuple {
             updatedByUser: this.updatedByUser,
             lastStage: this._lastStage,
             needsSave: this.needsSave,
-            replacementIds: this._replacementIds
+            replacementIds: this._replacementIds,
         };
 
         return JSON.stringify(data);
@@ -553,7 +629,8 @@ export class BranchTuple extends Tuple {
 
         this.packedJson__[BranchTuple.__DISPS_NUM] = data.disps;
         this.packedJson__[BranchTuple.__ANCHOR_DISP_KEYS_NUM] = data.anchors;
-        this.packedJson__[BranchTuple.__UPDATED_BY_USER_NUM] = data.updatedByUser;
+        this.packedJson__[BranchTuple.__UPDATED_BY_USER_NUM] =
+            data.updatedByUser;
         this.packedJson__[BranchTuple.__NEEDS_SAVE_NUM] = data.needsSave;
 
         this._replacementIds = data.replacementIds;
@@ -567,40 +644,12 @@ export class BranchTuple extends Tuple {
                 let dispval = disp[key];
 
                 // Nulls are not included
-                if (dispval == null)
-                    delete disp[key];
-
+                if (dispval == null) delete disp[key];
                 // Delete all the linked lookups, we just want the IDs
-                else if (dispval['__rst'] != null) // VortexJS Serialise Class Type
+                else if (dispval["__rst"] != null)
+                    // VortexJS Serialise Class Type
                     delete disp[key];
-
             }
         }
     }
-
-    linkDisps(lookupService: PrivateDiagramLookupService) {
-        for (let disp of this.disps) {
-            lookupService._linkDispLookups(disp);
-        }
-    }
-
-    setContextUpdateCallback(contextUpdateCallback: ((modelUpdateRequired: boolean) => void) | null) {
-        this._contextUpdateCallback = contextUpdateCallback;
-
-    }
-
-    applyLiveUpdate(liveEditTuple: BranchLiveEditTuple): boolean {
-        let liveUpdateTuple = liveEditTuple.branchTuple;
-
-        if (this.updatedDate == null
-            || moment(this.updatedDate).isBefore(liveUpdateTuple.updatedDate)
-            || liveEditTuple.updateFromSave) {
-            this.packedJson__ = liveUpdateTuple.packedJson__;
-            this.assignIdsToDisps();
-            this.resetUndo();
-            this.resetRedo();
-            return true;
-        }
-        return false;
-    }
 }
