@@ -1,14 +1,15 @@
-import {BranchTuple} from "./BranchTuple";
-import {BranchLiveEditTupleAction} from "./BranchLiveEditTupleAction";
-import {UserListItemTuple} from "@peek/peek_core_user";
-import {LocalBranchStorageService} from "../branch-loader/LocalBranchStorageService";
-import {BranchUpdateTupleAction} from "./BranchUpdateTupleAction";
-import {PrivateDiagramTupleService} from "../services";
-import {Observable, Subject} from "rxjs";
-import {TupleSelector, VortexStatusService} from "@synerty/vortexjs";
-import {BranchLiveEditTuple} from "./BranchLiveEditTuple";
-import { BalloonMsgService } from "@synerty/peek-plugin-base-js"
-import {PrivateDiagramLookupService} from "../services/PrivateDiagramLookupService";
+import { Observable, Subject } from "rxjs";
+import { takeUntil } from "rxjs/operators";
+import { BranchTuple } from "./BranchTuple";
+import { BranchLiveEditTupleAction } from "./BranchLiveEditTupleAction";
+import { UserListItemTuple } from "@peek/peek_core_user";
+import { LocalBranchStorageService } from "../branch-loader/LocalBranchStorageService";
+import { BranchUpdateTupleAction } from "./BranchUpdateTupleAction";
+import { PrivateDiagramTupleService } from "../services";
+import { TupleSelector, VortexStatusService } from "@synerty/vortexjs";
+import { BranchLiveEditTuple } from "./BranchLiveEditTuple";
+import { BalloonMsgService } from "@synerty/peek-plugin-base-js";
+import { PrivateDiagramLookupService } from "../services/PrivateDiagramLookupService";
 
 /** Diagram Branch Service
  *
@@ -16,26 +17,24 @@ import {PrivateDiagramLookupService} from "../services/PrivateDiagramLookupServi
  *
  */
 export class PrivateDiagramBranchContext {
-
+    private static readonly SEND_UPDATE_PERIOD = 2000;
     private readonly shutdownSubject = new Subject<void>();
     private readonly _branchUpdatedSubject = new Subject<boolean>();
-
-    private static readonly SEND_UPDATE_PERIOD = 2000;
     private updateTimerNum = null;
     private needsLiveUpdateSend = false;
 
-    constructor(private vortexStatusService: VortexStatusService,
-                private balloonMsg: BalloonMsgService,
-                private lookupCache: PrivateDiagramLookupService,
-                private branch: BranchTuple,
-                private _modelSetId: number,
-                private _modelSetKey: string,
-                private _coordSetKey: string,
-                private tupleService: PrivateDiagramTupleService,
-                private branchLocalLoader: LocalBranchStorageService,
-                private userDetails: UserListItemTuple) {
-
-    }
+    constructor(
+        private vortexStatusService: VortexStatusService,
+        private balloonMsg: BalloonMsgService,
+        private lookupCache: PrivateDiagramLookupService,
+        private branch: BranchTuple,
+        private _modelSetId: number,
+        private _modelSetKey: string,
+        private _coordSetKey: string,
+        private tupleService: PrivateDiagramTupleService,
+        private branchLocalLoader: LocalBranchStorageService,
+        private userDetails: UserListItemTuple
+    ) {}
 
     get branchTuple(): BranchTuple {
         return this.branch;
@@ -58,7 +57,7 @@ export class PrivateDiagramBranchContext {
      * The observable will be emitted with an
      */
     get branchUpdatedObservable(): Observable<boolean> {
-        return this._branchUpdatedSubject.takeUntil(this.shutdownSubject);
+        return this._branchUpdatedSubject.pipe(takeUntil(this.shutdownSubject));
     }
 
     async save(): Promise<void> {
@@ -84,28 +83,33 @@ export class PrivateDiagramBranchContext {
 
         let ts = new TupleSelector(BranchLiveEditTuple.tupleName, {
             coordSetId: this.branch.coordSetId,
-            key: this.branch.key
+            key: this.branch.key,
         });
 
         this.tupleService.observer
             .subscribeToTupleSelector(ts)
-            .takeUntil(this.shutdownSubject)
+            .pipe(takeUntil(this.shutdownSubject))
             .subscribe((tuples: BranchLiveEditTuple[]) => {
-                if (tuples.length == 0)
-                    return;
+                if (tuples.length == 0) return;
 
                 const update = tuples[0];
 
-                if (update.updateFromSave && update.updatedByUser != this.userKey()) {
-                    this.balloonMsg
-                        .showWarning("Another user has saved this diagram edit.");
+                if (
+                    update.updateFromSave &&
+                    update.updatedByUser != this.userKey()
+                ) {
+                    this.balloonMsg.showWarning(
+                        "Another user has saved this diagram edit."
+                    );
                 }
 
                 if (update.updateFromSave) {
-                    this.branchLocalLoader.saveBranch(this)
-                        .catch(
-                            e => console
-                                .log(`Failed to locally save update from server: ${e}`)
+                    this.branchLocalLoader
+                        .saveBranch(this)
+                        .catch((e) =>
+                            console.log(
+                                `Failed to locally save update from server: ${e}`
+                            )
                         );
                 }
 
@@ -115,16 +119,15 @@ export class PrivateDiagramBranchContext {
                 }
             });
 
-        this.updateTimerNum = setInterval(
-            () => {
-                if (this.needsLiveUpdateSend == false) return;
-                this.needsLiveUpdateSend = false;
-                this.sendLiveUpdate()
-            },
-            PrivateDiagramBranchContext.SEND_UPDATE_PERIOD);
+        this.updateTimerNum = setInterval(() => {
+            if (this.needsLiveUpdateSend == false) return;
+            this.needsLiveUpdateSend = false;
+            this.sendLiveUpdate();
+        }, PrivateDiagramBranchContext.SEND_UPDATE_PERIOD);
 
-        this.lookupCache.dispsNeedRelinkingObservable()
-            .takeUntil(this.shutdownSubject)
+        this.lookupCache
+            .dispsNeedRelinkingObservable()
+            .pipe(takeUntil(this.shutdownSubject))
             .subscribe(() => this.branchTuple.linkDisps(this.lookupCache));
     }
 
@@ -140,7 +143,6 @@ export class PrivateDiagramBranchContext {
     }
 
     private sendLiveUpdate(updateType: number | null = null): void {
-
         if (updateType == null)
             updateType = BranchLiveEditTupleAction.EDITING_UPDATED;
 
@@ -155,23 +157,19 @@ export class PrivateDiagramBranchContext {
             // All updates are only sent when the device is online
             if (this.vortexStatusService.snapshot.isOnline)
                 promise = this.tupleService.action.pushAction(action);
-
         } else {
             // ALL Start and Finish updates are sent
             promise = this.tupleService.offlineAction.pushAction(action);
         }
 
         if (promise != null) {
-            promise.catch(
-                e => console.log(`Failed to send live update for branch: ${e}`)
+            promise.catch((e) =>
+                console.log(`Failed to send live update for branch: ${e}`)
             );
         }
-
     }
 
     private userKey(): string {
         return `${this.userDetails.userTitle} (${this.userDetails.userName})`;
     }
-
-
 }
