@@ -1,7 +1,5 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {diagramTuplePrefix} from "../PluginNames";
-
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { diagramTuplePrefix } from "../PluginNames";
 
 @addTupleType
 export class EncodedGridTuple extends Tuple {
@@ -21,6 +19,14 @@ export class EncodedGridTuple extends Tuple {
     branchJsonStr: string | null;
 
     constructor() {
-        super(EncodedGridTuple.tupleName)
+        super(EncodedGridTuple.tupleName);
     }
-}
\ No newline at end of file
+
+    get chunkKey(): string {
+        return this.gridKey;
+    }
+
+    get encodedData(): string | null {
+        return this.encodedGridTuple;
+    }
+}
