@@ -1,6 +1,5 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {diagramTuplePrefix} from "@peek/peek_plugin_diagram/_private";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { diagramTuplePrefix } from "@peek/peek_plugin_diagram/_private";
 
 @addTupleType
 export class GridTuple extends Tuple {
@@ -13,6 +12,6 @@ export class GridTuple extends Tuple {
     lastUpdate: string;
 
     constructor() {
-        super(GridTuple.tupleName)
+        super(GridTuple.tupleName);
     }
 }
