@@ -1,10 +1,10 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {diagramTuplePrefix} from "@peek/peek_plugin_diagram/_private";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { diagramTuplePrefix } from "@peek/peek_plugin_diagram/_private";
 
 @addTupleType
 export class DispKeyLocationTuple extends Tuple {
-    public static readonly tupleName = diagramTuplePrefix + "DispKeyLocationTuple";
+    public static readonly tupleName =
+        diagramTuplePrefix + "DispKeyLocationTuple";
 
     coordSetKey: string;
     coordSetId: number;
@@ -15,7 +15,7 @@ export class DispKeyLocationTuple extends Tuple {
     y: number;
 
     constructor() {
-        super(DispKeyLocationTuple.tupleName)
+        super(DispKeyLocationTuple.tupleName);
     }
 
     static fromLocationJson(data: any[]): DispKeyLocationTuple {
@@ -26,4 +26,4 @@ export class DispKeyLocationTuple extends Tuple {
         self.y = data[3];
         return self;
     }
-}
\ No newline at end of file
+}
