@@ -1,41 +1,40 @@
-import {Injectable} from "@angular/core";
-import {LocationIndexTuple} from "./LocationIndexTuple";
-
+import { Observable, Subject } from "rxjs";
+import { filter, first, takeUntil } from "rxjs/operators";
+import { Injectable } from "@angular/core";
+import { LocationIndexTuple } from "./LocationIndexTuple";
 import {
-    ComponentLifecycleEventEmitter,
     extend,
+    NgLifeCycleEvents,
     Payload,
     PayloadEnvelope,
     TupleOfflineStorageNameService,
     TupleOfflineStorageService,
     TupleSelector,
+    TupleStorageBatchSaveArguments,
     TupleStorageFactoryService,
     VortexService,
-    VortexStatusService
+    VortexStatusService,
 } from "@synerty/vortexjs";
 import {
     diagramFilt,
-    locationIndexCacheStorageName
+    locationIndexCacheStorageName,
 } from "@peek/peek_plugin_diagram/_private";
-import {DiagramCoordSetService} from "@peek/peek_plugin_diagram/DiagramCoordSetService";
-
-
-import {LocationIndexUpdateDateTuple} from "./LocationIndexUpdateDateTuple";
-import {DispKeyLocationTuple} from "./DispKeyLocationTuple";
-import {PrivateDiagramCoordSetService} from "../services/PrivateDiagramCoordSetService";
-
-import {Subject} from "rxjs/Subject";
-import {Observable} from "rxjs/Observable";
-import {EncodedLocationIndexTuple} from "./EncodedLocationIndexTuple";
-import {PrivateDiagramLocationLoaderStatusTuple} from "./PrivateDiagramLocationLoaderStatusTuple";
-import {PrivateDiagramTupleService} from "../services/PrivateDiagramTupleService";
-import {OfflineConfigTuple} from "../tuples";
-
+import { DiagramCoordSetService } from "@peek/peek_plugin_diagram/DiagramCoordSetService";
+import { LocationIndexUpdateDateTuple } from "./LocationIndexUpdateDateTuple";
+import { DispKeyLocationTuple } from "./DispKeyLocationTuple";
+import { PrivateDiagramCoordSetService } from "../services/PrivateDiagramCoordSetService";
+import { EncodedLocationIndexTuple } from "./EncodedLocationIndexTuple";
+import { PrivateDiagramLocationLoaderStatusTuple } from "./PrivateDiagramLocationLoaderStatusTuple";
+import { PrivateDiagramTupleService } from "../services/PrivateDiagramTupleService";
+import {
+    DeviceOfflineCacheService,
+    OfflineCacheStatusTuple,
+} from "@peek/peek_core_device";
 
 // ----------------------------------------------------------------------------
 
 let clientLocationIndexWatchUpdateFromDeviceFilt = extend(
-    {'key': "clientLocationIndexWatchUpdateFromDevice"},
+    { key: "clientLocationIndexWatchUpdateFromDevice" },
     diagramFilt
 );
 
@@ -46,7 +45,7 @@ const cacheAll = "cacheAll";
  */
 class LocationIndexTupleSelector extends TupleSelector {
     constructor(indexBucket: string) {
-        super(LocationIndexTuple.tupleName, {key: indexBucket});
+        super(LocationIndexTuple.tupleName, { key: indexBucket });
     }
 }
 
@@ -59,7 +58,6 @@ class UpdateDateTupleSelector extends TupleSelector {
     }
 }
 
-
 // ----------------------------------------------------------------------------
 /** hash method
  */
@@ -67,17 +65,17 @@ let BUCKET_COUNT = 1024;
 
 function dispKeyHashBucket(modelSetKey: string, dispKey: string): string {
     /** Disp Key Hash Bucket
-
+     
      This method create an int from 0 to 255, representing the hash bucket for this
      key.
-
+     
      This is simple, and provides a reasonable distribution
-
+     
      @param modelSetKey:
      @param dispKey:
-
+     
      @return:
-
+     
      */
     if (modelSetKey == null || modelSetKey.length == 0)
         throw new Error("modelSetkey is None or zero length");
@@ -88,7 +86,7 @@ function dispKeyHashBucket(modelSetKey: string, dispKey: string): string {
     let hash = 0;
 
     for (let i = 0; i < dispKey.length; i++) {
-        hash = ((hash << 5) - hash) + dispKey.charCodeAt(i);
+        hash = (hash << 5) - hash + dispKey.charCodeAt(i);
         hash |= 0; // Convert to 32bit integer
     }
 
@@ -97,7 +95,6 @@ function dispKeyHashBucket(modelSetKey: string, dispKey: string): string {
     return `${modelSetKey}:${hash}`;
 }
 
-
 // ----------------------------------------------------------------------------
 /** PrivateDiagramLocationLoaderService Cache
  *
@@ -109,9 +106,14 @@ function dispKeyHashBucket(modelSetKey: string, dispKey: string): string {
  *
  */
 @Injectable()
-export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEventEmitter {
+export class PrivateDiagramLocationLoaderService extends NgLifeCycleEvents {
     private UPDATE_CHUNK_FETCH_SIZE = 5;
-    private OFFLINE_CHECK_PERIOD_MS = 15 * 60 * 1000; // 15 minutes
+
+    // Every 100 chunks from the server
+    private SAVE_POINT_ITERATIONS = 100;
+
+    // Saving the cache after each chunk is so expensive, we only do it every 20 or so
+    private chunksSavedSinceLastIndexSave = 0;
 
     private index = new LocationIndexUpdateDateTuple();
     private askServerChunks: LocationIndexUpdateDateTuple[] = [];
@@ -121,32 +123,24 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
 
     private storage: TupleOfflineStorageService;
 
-    private _statusSubject = new Subject<PrivateDiagramLocationLoaderStatusTuple>();
+    private _statusSubject =
+        new Subject<PrivateDiagramLocationLoaderStatusTuple>();
     private _status = new PrivateDiagramLocationLoaderStatusTuple();
 
-    private offlineConfig: OfflineConfigTuple = new OfflineConfigTuple();
-
     private coordSetService: PrivateDiagramCoordSetService;
 
-    constructor(private vortexService: VortexService,
-                private vortexStatusService: VortexStatusService,
-                storageFactory: TupleStorageFactoryService,
-                abstractCoordSetService: DiagramCoordSetService,
-                private tupleService: PrivateDiagramTupleService) {
+    constructor(
+        private vortexService: VortexService,
+        private vortexStatusService: VortexStatusService,
+        storageFactory: TupleStorageFactoryService,
+        abstractCoordSetService: DiagramCoordSetService,
+        private tupleService: PrivateDiagramTupleService,
+        private deviceCacheControllerService: DeviceOfflineCacheService
+    ) {
         super();
-        this.coordSetService = <PrivateDiagramCoordSetService>abstractCoordSetService;
-
-        this.tupleService.offlineObserver
-            .subscribeToTupleSelector(new TupleSelector(OfflineConfigTuple.tupleName, {}),
-                false, false, true)
-            .takeUntil(this.onDestroyEvent)
-            .filter(v => v.length != 0)
-            .subscribe((tuples: OfflineConfigTuple[]) => {
-                this.offlineConfig = tuples[0];
-                if (this.offlineConfig.cacheChunksForOffline)
-                    this.initialLoad();
-                this._notifyStatus();
-            });
+        this.coordSetService = <PrivateDiagramCoordSetService>(
+            abstractCoordSetService
+        );
 
         this.storage = new TupleOfflineStorageService(
             storageFactory,
@@ -156,10 +150,13 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
         this.setupVortexSubscriptions();
         this._notifyStatus();
 
-        // Check for updates every so often
-        Observable.interval(this.OFFLINE_CHECK_PERIOD_MS)
-            .takeUntil(this.onDestroyEvent)
-            .subscribe(() => this.askServerForUpdates());
+        this.deviceCacheControllerService.triggerCachingObservable
+            .pipe(takeUntil(this.onDestroyEvent))
+            .pipe(filter((v) => v))
+            .subscribe(() => {
+                this.initialLoad();
+                this._notifyStatus();
+            });
     }
 
     isReady(): boolean {
@@ -178,15 +175,86 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
         return this._status;
     }
 
+    /** Get Locations
+     *
+     * Get the location of a Disp.key from the index..
+     *
+     */
+    getLocations(
+        modelSetKey: string,
+        dispKey: string
+    ): Promise<DispKeyLocationTuple[]> {
+        if (
+            dispKey == null ||
+            dispKey.length == 0 ||
+            modelSetKey == null ||
+            modelSetKey.length == 0
+        ) {
+            let val: DispKeyLocationTuple[] = [];
+            return Promise.resolve(val);
+        }
+
+        // If there is no offline support, or we're online
+        if (this.vortexStatusService.snapshot.isOnline) {
+            let ts = new TupleSelector(DispKeyLocationTuple.tupleName, {
+                modelSetKey: modelSetKey,
+                keys: [dispKey],
+            });
+
+            let isOnlinePromise: any = this.vortexStatusService.snapshot
+                .isOnline
+                ? Promise.resolve()
+                : this.vortexStatusService.isOnline
+                      .pipe(filter((online) => online))
+                      .pipe(first())
+                      .toPromise();
+
+            return isOnlinePromise.then(() =>
+                this.tupleService.offlineObserver.pollForTuples(ts, false)
+            );
+        }
+
+        if (!this.deviceCacheControllerService.offlineModeEnabled) {
+            console.log(
+                "WARNING Offline support for Diagram is disabled," +
+                    " returning zero results"
+            );
+            return Promise.resolve([]);
+        }
+
+        // If we do have offline support
+        if (this.isReady())
+            return this.getLocationsFromLocal(modelSetKey, dispKey);
+
+        return this.isReadyObservable()
+            .pipe(first())
+            .toPromise()
+            .then(() => this.getLocationsFromLocal(modelSetKey, dispKey));
+    }
+
     private _notifyStatus(): void {
-        this._status.cacheForOfflineEnabled = this.offlineConfig.cacheChunksForOffline;
+        this._status.cacheForOfflineEnabled =
+            this.deviceCacheControllerService.cachingEnabled;
         this._status.initialLoadComplete = this.index.initialLoadComplete;
 
-        this._status.loadProgress = Object.keys(this.index.updateDateByChunkKey).length;
+        this._status.loadProgress = Object.keys(
+            this.index.updateDateByChunkKey
+        ).length;
         for (let chunk of this.askServerChunks)
-            this._status.loadProgress -= Object.keys(chunk.updateDateByChunkKey).length;
+            this._status.loadProgress -= Object.keys(
+                chunk.updateDateByChunkKey
+            ).length;
 
         this._statusSubject.next(this._status);
+
+        const status = new OfflineCacheStatusTuple();
+        status.pluginName = "peek_plugin_diagram";
+        status.indexName = "Position";
+        status.loadingQueueCount = this._status.loadProgress;
+        status.totalLoadedCount = this._status.loadTotal;
+        status.lastCheckDate = new Date();
+        status.initialFullLoadComplete = this._status.initialLoadComplete;
+        this.deviceCacheControllerService.updateCachingStatus(status);
     }
 
     /** Initial load
@@ -194,8 +262,8 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
      * Load the dates of the index buckets and ask the server if it has any updates.
      */
     private initialLoad(): void {
-
-        this.storage.loadTuples(new UpdateDateTupleSelector())
+        this.storage
+            .loadTuples(new UpdateDateTupleSelector())
             .then((tuplesAny: any[]) => {
                 let tuples: LocationIndexUpdateDateTuple[] = tuplesAny;
                 if (tuples.length != 0) {
@@ -209,37 +277,37 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
 
                 this.askServerForUpdates();
                 this._notifyStatus();
-
             });
 
         this._notifyStatus();
-
     }
 
     private setupVortexSubscriptions(): void {
-
         // Services don't have destructors, I'm not sure how to unsubscribe.
-        this.vortexService.createEndpointObservable(this,
-            clientLocationIndexWatchUpdateFromDeviceFilt)
-            .takeUntil(this.onDestroyEvent)
+        this.vortexService
+            .createEndpointObservable(
+                this,
+                clientLocationIndexWatchUpdateFromDeviceFilt
+            )
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((payloadEnvelope: PayloadEnvelope) => {
-                this.processLocationIndexesFromServer(payloadEnvelope);
+                this.processChunksFromServer(payloadEnvelope);
             });
 
         // If the vortex service comes back online, update the watch grids.
         this.vortexStatusService.isOnline
-            .filter(isOnline => isOnline == true)
-            .takeUntil(this.onDestroyEvent)
+            .pipe(filter((isOnline) => isOnline == true))
+            .pipe(takeUntil(this.onDestroyEvent))
             .subscribe(() => this.askServerForUpdates());
-
     }
 
     private areWeTalkingToTheServer(): boolean {
-        return this.offlineConfig.cacheChunksForOffline
-            && this.vortexStatusService.snapshot.isOnline;
+        return (
+            this.deviceCacheControllerService.offlineModeEnabled &&
+            this.vortexStatusService.snapshot.isOnline
+        );
     }
 
-
     /** Ask Server For Updates
      *
      * Tell the server the state of the chunks in our index and ask if there
@@ -266,20 +334,31 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
 
                 // Tuples is an array of strings
                 for (let chunkKey of keys) {
-                    if (!this.index.updateDateByChunkKey.hasOwnProperty(chunkKey)) {
+                    if (
+                        !this.index.updateDateByChunkKey.hasOwnProperty(
+                            chunkKey
+                        )
+                    ) {
                         this.index.updateDateByChunkKey[chunkKey] = null;
                         keysNeedingUpdate.push(chunkKey);
-
-                    } else if (this.index.updateDateByChunkKey[chunkKey]
-                        != serverIndex.updateDateByChunkKey[chunkKey]) {
+                    } else if (
+                        this.index.updateDateByChunkKey[chunkKey] !=
+                        serverIndex.updateDateByChunkKey[chunkKey]
+                    ) {
                         keysNeedingUpdate.push(chunkKey);
                     }
                 }
+
+                if (
+                    keysNeedingUpdate.length === 0 &&
+                    !this.index.initialLoadComplete
+                )
+                    this.index.initialLoadComplete = true;
+
                 this.queueChunksToAskServer(keysNeedingUpdate);
             });
     }
 
-
     /** Queue Chunks To Ask Server
      *
      */
@@ -292,7 +371,8 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
         let indexChunk = new LocationIndexUpdateDateTuple();
 
         for (let key of keysNeedingUpdate) {
-            indexChunk.updateDateByChunkKey[key] = this.index.updateDateByChunkKey[key];
+            indexChunk.updateDateByChunkKey[key] =
+                this.index.updateDateByChunkKey[key] || "";
             count++;
 
             if (count == this.UPDATE_CHUNK_FETCH_SIZE) {
@@ -302,8 +382,7 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
             }
         }
 
-        if (count)
-            this.askServerChunks.push(indexChunk);
+        if (count) this.askServerChunks.push(indexChunk);
 
         this.askServerForNextUpdateChunk();
 
@@ -311,105 +390,109 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
         this._notifyStatus();
     }
 
-
     private askServerForNextUpdateChunk() {
         if (!this.areWeTalkingToTheServer()) return;
 
-        if (this.askServerChunks.length == 0)
-            return;
+        if (this.askServerChunks.length == 0) return;
 
-        let indexChunk: LocationIndexUpdateDateTuple = this.askServerChunks.pop();
+        this.deviceCacheControllerService //
+            .waitForGarbageCollector()
+            .then(() => {
+                let indexChunk: LocationIndexUpdateDateTuple =
+                    this.askServerChunks.pop();
 
-        let filt = extend({}, clientLocationIndexWatchUpdateFromDeviceFilt);
-        filt[cacheAll] = true;
-        let payload = new Payload(filt, [indexChunk]);
-        this.vortexService.sendPayload(payload);
+                let filt = extend(
+                    {},
+                    clientLocationIndexWatchUpdateFromDeviceFilt
+                );
+                filt[cacheAll] = true;
+                let payload = new Payload(filt, [indexChunk]);
+                this.vortexService.sendPayload(payload);
 
-        this._status.lastCheck = new Date();
+                this._status.lastCheck = new Date();
+                this._notifyStatus();
+            });
     }
 
-
     /** Process LocationIndexes From Server
      *
      * Process the grids the server has sent us.
      */
-    private processLocationIndexesFromServer(payloadEnvelope: PayloadEnvelope) {
-
+    private async processChunksFromServer(
+        payloadEnvelope: PayloadEnvelope
+    ): Promise<void> {
         if (payloadEnvelope.result != null && payloadEnvelope.result != true) {
             console.log(`ERROR: ${payloadEnvelope.result}`);
             return;
         }
 
-        payloadEnvelope
-            .decodePayload()
-            .then((payload: Payload) => this.storeLocationIndexPayload(payload))
-            .then(() => {
-                if (this.askServerChunks.length == 0) {
-                    this.index.initialLoadComplete = true;
-                    this._hasLoaded = true;
-                    this._hasLoadedSubject.next();
+        const tuplesToSave: EncodedLocationIndexTuple[] = <
+            EncodedLocationIndexTuple[]
+        >payloadEnvelope.data;
 
-                } else if (payloadEnvelope.filt[cacheAll] == true) {
-                    this.askServerForNextUpdateChunk();
+        try {
+            await this.storeChunkTuples(tuplesToSave);
+        } catch (e) {
+            console.log(`LocationIndexCache.storeChunkTuples: ${e}`);
+        }
 
-                }
-
-            })
-            .then(() => this._notifyStatus())
-            .catch(e =>
-                `LocationIndexCache.processLocationIndexesFromServer failed: ${e}`
-            );
-
-    }
-
-    private storeLocationIndexPayload(payload: Payload) {
-
-        let tuplesToSave: EncodedLocationIndexTuple[] = <EncodedLocationIndexTuple[]>payload.tuples;
-        if (tuplesToSave.length == 0)
-            return;
-
-        // 2) Store the index
-        this.storeLocationIndexTuples(tuplesToSave)
-            .then(() => {
-                // 3) Store the update date
-
-                for (let locationIndex of tuplesToSave) {
-                    this.index.updateDateByChunkKey[locationIndex.indexBucket] = locationIndex.lastUpdate;
-                }
-
-                return this.storage.saveTuples(
-                    new UpdateDateTupleSelector(), [this.index]
-                );
-
-            })
-            .catch(e => console.log(
-                `LocationIndexCache.storeLocationIndexPayload: ${e}`));
+        if (this.askServerChunks.length == 0) {
+            this.index.initialLoadComplete = true;
+            await this.saveChunkCacheIndex(true);
+            this._hasLoaded = true;
+            this._hasLoadedSubject.next();
+        } else if (payloadEnvelope.filt[cacheAll] == true) {
+            this.askServerForNextUpdateChunk();
+        }
 
+        this._notifyStatus();
     }
 
     /** Store Index Bucket
      * Stores the index bucket in the local db.
      */
-    private storeLocationIndexTuples(encodedLocationIndexTuples: EncodedLocationIndexTuple[]): Promise<void> {
-        let retPromise: any;
-        retPromise = this.storage.transaction(true)
-            .then((tx) => {
+    private async storeChunkTuples(
+        tuplesToSave: EncodedLocationIndexTuple[]
+    ): Promise<void> {
+        // noinspection BadExpressionStatementJS
+        const Selector = LocationIndexTupleSelector;
 
-                let promises = [];
+        if (tuplesToSave.length == 0) return;
 
-                for (let encodedLocationIndexTuple of encodedLocationIndexTuples) {
-                    promises.push(
-                        tx.saveTuplesEncoded(
-                            new LocationIndexTupleSelector(encodedLocationIndexTuple.indexBucket),
-                            encodedLocationIndexTuple.encodedLocationIndexTuple
-                        )
-                    );
-                }
-
-                return Promise.all(promises)
-                    .then(() => tx.close());
+        const batchStore: TupleStorageBatchSaveArguments[] = [];
+        for (const tuple of tuplesToSave) {
+            batchStore.push({
+                tupleSelector: new Selector(tuple.chunkKey),
+                vortexMsg: tuple.encodedData,
             });
-        return retPromise;
+        }
+
+        await this.storage.batchSaveTuplesEncoded(batchStore);
+
+        for (const tuple of tuplesToSave) {
+            this.index.updateDateByChunkKey[tuple.chunkKey] = tuple.lastUpdate;
+        }
+        await this.saveChunkCacheIndex();
+    }
+
+    /** Store Chunk Cache Index
+     *
+     * Updates our running tab of the update dates of the cached chunks
+     *
+     */
+    private async saveChunkCacheIndex(force = false): Promise<void> {
+        if (
+            this.chunksSavedSinceLastIndexSave <= this.SAVE_POINT_ITERATIONS &&
+            !force
+        ) {
+            return;
+        }
+
+        this.chunksSavedSinceLastIndexSave = 0;
+
+        await this.storage.saveTuples(new UpdateDateTupleSelector(), [
+            this.index,
+        ]);
     }
 
     /** Get Locations
@@ -417,51 +500,10 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
      * Get the location of a Disp.key from the index..
      *
      */
-    getLocations(modelSetKey: string, dispKey: string): Promise<DispKeyLocationTuple[]> {
-        if (dispKey == null || dispKey.length == 0
-            || modelSetKey == null || modelSetKey.length == 0) {
-            let val: DispKeyLocationTuple[] = [];
-            return Promise.resolve(val);
-        }
-
-        // If there is no offline support, or we're online
-        if (!this.offlineConfig.cacheChunksForOffline
-            || this.vortexStatusService.snapshot.isOnline) {
-            let ts = new TupleSelector(DispKeyLocationTuple.tupleName, {
-                "modelSetKey": modelSetKey,
-                "keys": [dispKey]
-            });
-
-            let isOnlinePromise: any = this.vortexStatusService.snapshot.isOnline ?
-                Promise.resolve() :
-                this.vortexStatusService.isOnline
-                    .filter(online => online)
-                    .first()
-                    .toPromise();
-
-            return isOnlinePromise
-                .then(() => this.tupleService.offlineObserver.pollForTuples(ts, false));
-        }
-
-        // If we do have offline support
-        if (this.isReady())
-            return this.getLocationsFromLocal(modelSetKey, dispKey);
-
-        return this.isReadyObservable()
-            .first()
-            .toPromise()
-            .then(() => this.getLocationsFromLocal(modelSetKey, dispKey));
-
-
-    }
-
-    /** Get Locations
-     *
-     * Get the location of a Disp.key from the index..
-     *
-     */
-    private getLocationsFromLocal(modelSetKey: string, dispKey: string): Promise<DispKeyLocationTuple[]> {
-
+    private getLocationsFromLocal(
+        modelSetKey: string,
+        dispKey: string
+    ): Promise<DispKeyLocationTuple[]> {
         let indexBucket = dispKeyHashBucket(modelSetKey, dispKey);
 
         if (!this.index.updateDateByChunkKey.hasOwnProperty(indexBucket)) {
@@ -470,10 +512,10 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
         }
 
         let retPromise: any;
-        retPromise = this.storage.loadTuples(new LocationIndexTupleSelector(indexBucket))
+        retPromise = this.storage
+            .loadTuples(new LocationIndexTupleSelector(indexBucket))
             .then((tuples: LocationIndexTuple[]) => {
-                if (tuples.length == 0)
-                    return [];
+                if (tuples.length == 0) return [];
 
                 if (tuples.length != 1)
                     throw new Error("We received more tuples then expected");
@@ -491,18 +533,18 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
                 }
 
                 // If we didn't find the key, return no indexes
-                if (dispLocationIndexRawData == null)
-                    return [];
+                if (dispLocationIndexRawData == null) return [];
 
                 let dispIndexes: DispKeyLocationTuple[] = [];
                 for (let rawData of dispLocationIndexRawData) {
-                    let dispLocation = DispKeyLocationTuple.fromLocationJson(rawData);
+                    let dispLocation =
+                        DispKeyLocationTuple.fromLocationJson(rawData);
 
-                    let coordSet = this.coordSetService
-                        .coordSetForId(dispLocation.coordSetId);
+                    let coordSet = this.coordSetService.coordSetForId(
+                        dispLocation.coordSetId
+                    );
 
-                    if (coordSet == null)
-                        continue;
+                    if (coordSet == null) continue;
 
                     dispLocation.coordSetKey = coordSet.key;
 
@@ -512,7 +554,5 @@ export class PrivateDiagramLocationLoaderService extends ComponentLifecycleEvent
                 return dispIndexes;
             });
         return retPromise;
-
     }
-
-}
\ No newline at end of file
+}
