@@ -1,11 +1,10 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {diagramTuplePrefix} from "../PluginNames";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { diagramTuplePrefix } from "../PluginNames";
 
 @addTupleType
 export class PrivateDiagramLocationLoaderStatusTuple extends Tuple {
-    public static readonly tupleName = diagramTuplePrefix + "PrivateDiagramLocationLoaderStatusTuple";
-
+    public static readonly tupleName =
+        diagramTuplePrefix + "PrivateDiagramLocationLoaderStatusTuple";
 
     cacheForOfflineEnabled: boolean = false;
     initialLoadComplete: boolean = false;
@@ -14,6 +13,6 @@ export class PrivateDiagramLocationLoaderStatusTuple extends Tuple {
     lastCheck: Date;
 
     constructor() {
-        super(PrivateDiagramLocationLoaderStatusTuple.tupleName)
+        super(PrivateDiagramLocationLoaderStatusTuple.tupleName);
     }
 }
