@@ -1,13 +1,12 @@
-import {Injectable} from "@angular/core";
-import {Subject} from "rxjs/Subject";
-import {Observable} from "rxjs/Observable";
+import { Injectable } from "@angular/core";
+import { Subject } from "rxjs";
+import { Observable } from "rxjs";
 import {
     DiagramItemSelectService,
-    SelectedItemDetailsI
+    SelectedItemDetailsI,
 } from "../../DiagramItemSelectService";
 
-
-export {SelectedItemDetailsI} from "../../DiagramItemSelectService";
+export { SelectedItemDetailsI } from "../../DiagramItemSelectService";
 
 /** Item Select Service
  *
@@ -18,12 +17,10 @@ export {SelectedItemDetailsI} from "../../DiagramItemSelectService";
  */
 @Injectable()
 export class PrivateDiagramItemSelectService extends DiagramItemSelectService {
-
     private itemSelectSubject = new Subject<SelectedItemDetailsI[]>();
 
     constructor() {
         super();
-
     }
 
     itemsSelectedObservable(): Observable<SelectedItemDetailsI[]> {
@@ -33,5 +30,4 @@ export class PrivateDiagramItemSelectService extends DiagramItemSelectService {
     selectItems(details: SelectedItemDetailsI[]): void {
         this.itemSelectSubject.next(details);
     }
-
-}
\ No newline at end of file
+}
