@@ -1,6 +1,5 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {diagramTuplePrefix} from "../PluginNames";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { diagramTuplePrefix } from "../PluginNames";
 
 @addTupleType
 export class ModelSet extends Tuple {
@@ -12,9 +11,6 @@ export class ModelSet extends Tuple {
     comment: string;
 
     constructor() {
-        super(ModelSet.tupleName)
+        super(ModelSet.tupleName);
     }
-
 }
-
-
