@@ -1,6 +1,5 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {diagramTuplePrefix} from "@peek/peek_plugin_diagram/_private";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { diagramTuplePrefix } from "@peek/peek_plugin_diagram/_private";
 
 @addTupleType
 export class DispLayer extends Tuple {
@@ -14,6 +13,6 @@ export class DispLayer extends Tuple {
     modelSetId: number;
 
     constructor() {
-        super(DispLayer.tupleName)
+        super(DispLayer.tupleName);
     }
-}
\ No newline at end of file
+}
