@@ -1,6 +1,5 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {diagramTuplePrefix} from "@peek/peek_plugin_diagram/_private";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { diagramTuplePrefix } from "@peek/peek_plugin_diagram/_private";
 
 @addTupleType
 export class DispLevel extends Tuple {
@@ -14,7 +13,7 @@ export class DispLevel extends Tuple {
     coordSetId: number;
 
     constructor() {
-        super(DispLevel.tupleName)
+        super(DispLevel.tupleName);
     }
 
     isVisibleAtZoom(zoom: number): boolean {
