@@ -1,6 +1,5 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {diagramTuplePrefix} from "@peek/peek_plugin_diagram/_private";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { diagramTuplePrefix } from "@peek/peek_plugin_diagram/_private";
 
 @addTupleType
 export class DispLineStyle extends Tuple {
@@ -30,7 +29,9 @@ export class DispLineStyle extends Tuple {
 
     modelSetId: number;
 
+    scalable: boolean;
+
     constructor() {
-        super(DispLineStyle.tupleName)
+        super(DispLineStyle.tupleName);
     }
-}
\ No newline at end of file
+}
