@@ -1,6 +1,5 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {diagramTuplePrefix} from "@peek/peek_plugin_diagram/_private";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { diagramTuplePrefix } from "@peek/peek_plugin_diagram/_private";
 
 @addTupleType
 export class DispTextStyle extends Tuple {
@@ -14,8 +13,10 @@ export class DispTextStyle extends Tuple {
     scalable: boolean;
     scaleFactor: number;
     modelSetId: number;
+    spacingBetweenTexts: number;
+    borderWidth: number;
 
     constructor() {
-        super(DispTextStyle.tupleName)
+        super(DispTextStyle.tupleName);
     }
-}
\ No newline at end of file
+}
