@@ -7,18 +7,14 @@ from peek_plugin_diagram._private.PluginNames import diagramTuplePrefix
 
 @addTupleType
 class ImportDispLineStyleTuple(Tuple):
-    """ Import Display Line Style Tuple
-
-
-    """
-    __tupleType__ = diagramTuplePrefix + 'ImportDispLineStyleTuple'
-
+    """Import Display Line Style Tuple"""
 
+    __tupleType__ = diagramTuplePrefix + "ImportDispLineStyleTuple"
 
     name: str = TupleField()
 
     #: Fill the dash space, or let the what ever is underneath show.
-    backgroundFillDashSpace: bool = TupleField()
+    backgroundFillDashSpace: bool = TupleField(defaultValue=False)
 
     CAP_BUTT = "butt"
     CAP_ROUND = "round"
@@ -40,8 +36,14 @@ class ImportDispLineStyleTuple(Tuple):
     # * None
     # an integer
     # a list of integers
-    dashPattern: Optional[Union[List[int],int]] = TupleField()
+    dashPattern: Optional[Union[List[int], int]] = TupleField()
 
     importHash: str = TupleField()
 
     modelSetKey: str = TupleField()
+
+    scalable: bool = TupleField(defaultValue=True)
+
+    showForEdit: bool = TupleField(defaultValue=False)
+
+    blockApiUpdate: bool = TupleField(defaultValue=False)
