@@ -4,16 +4,16 @@ from vortex.Tuple import Tuple, addTupleType, TupleField
 
 @addTupleType
 class DiagramCoordSetTuple(Tuple):
-    """ Diagram Coordinate Set Tuple
+    """Diagram Coordinate Set Tuple
 
     This tuple represents a coordinate set in the diagram data storage.
 
     """
-    __tupleType__ = diagramTuplePrefix + 'DiagramCoordSetTuple'
+
+    __tupleType__ = diagramTuplePrefix + "DiagramCoordSetTuple"
 
     #:  The ID of the coordinate set.
     key: int = TupleField()
 
     #:  The name of the coordinate set.
     name: str = TupleField()
-
